@@ -1,12 +1,8 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=too-many-lines
 """
-:mod:`orion.core.evc.adapters` -- Adapters to connect experiments within the EVC system
-=======================================================================================
-
-.. module:: adapters
-   :platform: Unix
-   :synopsis: Adapters to connect experiments within the EVC system
+Adapters to connect experiments within the EVC system
+=====================================================
 
 Experiment branches because of changes in the configuration or the user's code. This make
 experiments incompatible with one another unless we define adapters such that a branched experiment
@@ -34,8 +30,8 @@ Adapters can be build using the factory class `Adapter(**kwargs)` or using
 `Adapter.build(list_of_dicts)`.
 
 """
-from abc import (ABCMeta, abstractmethod)
 import copy
+from abc import ABCMeta, abstractmethod
 
 from orion.core.io.space_builder import DimensionBuilder
 from orion.core.utils import Factory
@@ -133,10 +129,15 @@ class CompositeAdapter(BaseAdapter):
 
         """
         if any(not isinstance(adapter, BaseAdapter) for adapter in adapters):
-            wrong_object_type = [type(adapter) for adapter in adapters
-                                 if not isinstance(adapter, BaseAdapter)][0]
-            raise TypeError("Provided adapters must be adapter objects, not '%s'" %
-                            str(wrong_object_type))
+            wrong_object_type = [
+                type(adapter)
+                for adapter in adapters
+                if not isinstance(adapter, BaseAdapter)
+            ][0]
+            raise TypeError(
+                "Provided adapters must be adapter objects, not '%s'"
+                % str(wrong_object_type)
+            )
 
         self.adapters = adapters
 
@@ -145,7 +146,7 @@ class CompositeAdapter(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         for adapter in self.adapters:
             trials = adapter.forward(trials)
@@ -157,7 +158,7 @@ class CompositeAdapter(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.backward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.backward`
         """
         for adapter in self.adapters[::-1]:
             trials = adapter.backward(trials)
@@ -180,13 +181,15 @@ class CompositeAdapter(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.configuration`
+            :meth:`orion.core.evc.adapters.BaseAdapter.configuration`
         """
         if len(self.adapters) > 1:
-            return [adapter.configuration
-                    if len(adapter.configuration) > 1
-                    else adapter.configuration[0]
-                    for adapter in self.adapters]
+            return [
+                adapter.configuration
+                if len(adapter.configuration) > 1
+                else adapter.configuration[0]
+                for adapter in self.adapters
+            ]
         elif self.adapters:
             return self.adapters[0].configuration
 
@@ -222,9 +225,10 @@ def apply_if_valid(name, trial, callback=None, raise_if_not=True):
             return callback is None or callback(trial, param)
 
     if raise_if_not:
-        raise RuntimeError("Provided trial does not have a compatible configuration. "
-                           "A dimension named '%s' should be present.\n %s" %
-                           (name, trial))
+        raise RuntimeError(
+            "Provided trial does not have a compatible configuration. "
+            "A dimension named '%s' should be present.\n %s" % (name, trial)
+        )
 
     return False
 
@@ -259,10 +263,11 @@ class DimensionAddition(BaseAdapter):
         if isinstance(param, dict):
             param = Trial.Param(**param)
         elif not isinstance(param, Trial.Param):
-            raise TypeError("Invalid param argument type ('%s'). "
-                            "Param argument must be a Param object or a dictionnary "
-                            "as defined by Trial.Param.to_dict()." %
-                            str(type(param)))
+            raise TypeError(
+                "Invalid param argument type ('%s'). "
+                "Param argument must be a Param object or a dictionnary "
+                "as defined by Trial.Param.to_dict()." % str(type(param))
+            )
 
         self.param = param
 
@@ -271,15 +276,17 @@ class DimensionAddition(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         adapted_trials = []
 
         for trial in trials:
             if apply_if_valid(self.param.name, trial, raise_if_not=False):
-                raise RuntimeError("Provided trial does not have a compatible configuration. "
-                                   "A dimension named '%s' was already present.\n %s" %
-                                   (self.param.name, trial))
+                raise RuntimeError(
+                    "Provided trial does not have a compatible configuration. "
+                    "A dimension named '%s' was already present.\n %s"
+                    % (self.param.name, trial)
+                )
 
             adapted_trial = copy.deepcopy(trial)
             # pylint: disable=protected-access
@@ -293,7 +300,7 @@ class DimensionAddition(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.backward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.backward`
         """
         adapted_trials = []
 
@@ -320,9 +327,7 @@ class DimensionAddition(BaseAdapter):
 
             :meth:`orion.core.evc.adapters.BaseAdapter.to_dict`
         """
-        ret = dict(
-            of_type=self.__class__.__name__.lower(),
-            param=self.param.to_dict())
+        ret = dict(of_type=self.__class__.__name__.lower(), param=self.param.to_dict())
         return ret
 
 
@@ -370,8 +375,8 @@ class DimensionDeletion(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.DimensionAddition.backward`
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.DimensionAddition.backward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         return self.dimension_addition_adapter.backward(trials)
 
@@ -380,8 +385,8 @@ class DimensionDeletion(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.DimensionAddition.forward`
-            :meth:`orion.core.evc.BaseAdapter.backward`
+            :meth:`orion.core.evc.adapters.DimensionAddition.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.backward`
         """
         return self.dimension_addition_adapter.forward(trials)
 
@@ -393,7 +398,7 @@ class DimensionDeletion(BaseAdapter):
             :meth:`orion.core.evc.adapters.BaseAdapter.to_dict`
         """
         ret = self.dimension_addition_adapter.to_dict()
-        ret['of_type'] = 'dimensiondeletion'
+        ret["of_type"] = "dimensiondeletion"
         return ret
 
 
@@ -434,35 +439,42 @@ class DimensionPriorChange(BaseAdapter):
         self.name = name
         self.old_prior = old_prior
         self.new_prior = new_prior
-        self.old_dimension = DimensionBuilder().build('old', old_prior)
-        self.new_dimension = DimensionBuilder().build('new', new_prior)
+        self.old_dimension = DimensionBuilder().build("old", old_prior)
+        self.new_dimension = DimensionBuilder().build("new", new_prior)
 
         if self.old_dimension.shape != self.new_dimension.shape:
-            raise NotImplementedError("Oríon does not support yet adaptations on prior "
-                                      "shape changes.")
+            raise NotImplementedError(
+                "Oríon does not support yet adaptations on prior " "shape changes."
+            )
 
     def forward(self, trials):
         """Filter out trials which have out of bound values based on the child's prior.
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         # pylint: disable=unused-argument
         def is_in_bound(trial, param):
             """Test if param's value is in the new prior's bounds"""
             return param.value in self.new_dimension
 
-        return [trial for trial in trials if apply_if_valid(self.name, trial, callback=is_in_bound)]
+        return [
+            trial
+            for trial in trials
+            if apply_if_valid(self.name, trial, callback=is_in_bound)
+        ]
 
     def backward(self, trials):
         """Filter out trials which have out of bound values based on the parent's prior.
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.backward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.backward`
         """
-        return DimensionPriorChange(self.name, self.new_prior, self.old_prior).forward(trials)
+        return DimensionPriorChange(self.name, self.new_prior, self.old_prior).forward(
+            trials
+        )
 
     def to_dict(self):
         """Provide the configuration of the adapter as a dictionary
@@ -475,7 +487,8 @@ class DimensionPriorChange(BaseAdapter):
             of_type=self.__class__.__name__.lower(),
             name=self.name,
             old_prior=self.old_prior,
-            new_prior=self.new_prior)
+            new_prior=self.new_prior,
+        )
         return ret
 
 
@@ -506,10 +519,13 @@ class DimensionRenaming(BaseAdapter):
 
         """
         if any(not isinstance(name, str) for name in [old_name, new_name]):
-            wrong_object_type = [type(name) for name in [old_name, new_name]
-                                 if not isinstance(name, str)][0]
-            raise TypeError("Invalid name type '%s'. Names must be strings." %
-                            str(wrong_object_type))
+            wrong_object_type = [
+                type(name) for name in [old_name, new_name] if not isinstance(name, str)
+            ][0]
+            raise TypeError(
+                "Invalid name type '%s'. Names must be strings."
+                % str(wrong_object_type)
+            )
         self.old_name = old_name
         self.new_name = new_name
 
@@ -518,7 +534,7 @@ class DimensionRenaming(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         # pylint: disable=unused-argument
         def rename(trial, param):
@@ -538,7 +554,7 @@ class DimensionRenaming(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         return DimensionRenaming(self.new_name, self.old_name).forward(trials)
 
@@ -552,7 +568,8 @@ class DimensionRenaming(BaseAdapter):
         ret = dict(
             of_type=self.__class__.__name__.lower(),
             old_name=self.old_name,
-            new_name=self.new_name)
+            new_name=self.new_name,
+        )
         return ret
 
 
@@ -570,7 +587,7 @@ class AlgorithmChange(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         return trials
 
@@ -579,7 +596,7 @@ class AlgorithmChange(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         return trials
 
@@ -590,8 +607,7 @@ class AlgorithmChange(BaseAdapter):
 
             :meth:`orion.core.evc.adapters.BaseAdapter.to_dict`
         """
-        ret = dict(
-            of_type=self.__class__.__name__.lower())
+        ret = dict(of_type=self.__class__.__name__.lower())
         return ret
 
 
@@ -609,8 +625,8 @@ class CodeChange(BaseAdapter):
     Attributes
     ----------
     change_type: `str`
-        Type of change of the code. Can be one of `CodeChange.NOEFFET`, `CodeChange.BREAK` or
-        `CodeChange.UNSURE`.
+        Type of change of the code. Can be one of ``CodeChange.NOEFFET``, ``CodeChange.BREAK`` or
+        ``CodeChange.UNSURE``.
 
     """
 
@@ -625,8 +641,8 @@ class CodeChange(BaseAdapter):
         Parameters
         ----------
         change_type: `str`
-            Type of change of the code. Can be one of `CodeChange.NOEFFET`, `CodeChange.BREAK` or
-            `CodeChange.UNSURE`.
+            Type of change of the code. Can be one of ``CodeChange.NOEFFET``, ``CodeChange.BREAK``
+            or ``CodeChange.UNSURE``.
 
         """
         self.validate(change_type)
@@ -636,15 +652,17 @@ class CodeChange(BaseAdapter):
     def validate(cls, change_type):
         """Validate change type and raise ValueError if invalid"""
         if change_type not in cls.types:
-            raise ValueError("Invalid code change type '%s'. Should be one of %s" %
-                             (change_type, str(cls.types)))
+            raise ValueError(
+                "Invalid code change type '%s'. Should be one of %s"
+                % (change_type, str(cls.types))
+            )
 
     def forward(self, trials):
         """Filter out parent's trials if type of code change is BREAK.
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         if self.change_type == self.BREAK:
             return []
@@ -656,7 +674,7 @@ class CodeChange(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.backward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.backward`
         """
         if self.change_type in [self.BREAK, self.UNSURE]:
             return []
@@ -671,8 +689,8 @@ class CodeChange(BaseAdapter):
             :meth:`orion.core.evc.adapters.BaseAdapter.to_dict`
         """
         ret = dict(
-            of_type=self.__class__.__name__.lower(),
-            change_type=self.change_type)
+            of_type=self.__class__.__name__.lower(), change_type=self.change_type
+        )
         return ret
 
 
@@ -690,8 +708,8 @@ class CommandLineChange(BaseAdapter):
     Attributes
     ----------
     change_type: `str`
-        Type of change of the command line. Can be one of `CommandLineChange.NOEFFET`,
-        `CommandLineChange.BREAK` or `CommandLineChange.UNSURE`.
+        Type of change of the command line. Can be one of ``CommandLineChange.NOEFFET``,
+        ``CommandLineChange.BREAK`` or ``CommandLineChange.UNSURE``.
 
     """
 
@@ -706,8 +724,8 @@ class CommandLineChange(BaseAdapter):
         Parameters
         ----------
         change_type: `str`
-            Type of change of the command line. Can be one of `Change.NOEFFET`,
-            `CommandLineChange.BREAK` or `CommandLineChange.UNSURE`.
+            Type of change of the command line. Can be one of ``Change.NOEFFET``,
+            ``CommandLineChange.BREAK`` or ``CommandLineChange.UNSURE``.
 
         """
         self.validate(change_type)
@@ -717,15 +735,17 @@ class CommandLineChange(BaseAdapter):
     def validate(cls, change_type):
         """Validate change type and raise ValueError if invalid"""
         if change_type not in cls.types:
-            raise ValueError("Invalid cli change type '%s'. Should be one of %s" %
-                             (change_type, str(cls.types)))
+            raise ValueError(
+                "Invalid cli change type '%s'. Should be one of %s"
+                % (change_type, str(cls.types))
+            )
 
     def forward(self, trials):
         """Filter out parent's trials if type of cli change is BREAK.
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         if self.change_type == self.BREAK:
             return []
@@ -737,7 +757,7 @@ class CommandLineChange(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.backward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.backward`
         """
         if self.change_type in [self.BREAK, self.UNSURE]:
             return []
@@ -752,8 +772,8 @@ class CommandLineChange(BaseAdapter):
             :meth:`orion.core.evc.adapters.BaseAdapter.to_dict`
         """
         ret = dict(
-            of_type=self.__class__.__name__.lower(),
-            change_type=self.change_type)
+            of_type=self.__class__.__name__.lower(), change_type=self.change_type
+        )
         return ret
 
 
@@ -771,8 +791,8 @@ class ScriptConfigChange(BaseAdapter):
     Attributes
     ----------
     change_type: `str`
-        Type of change of the command line. Can be one of `ScriptConfigChange.NOEFFET`,
-        `ScriptConfigChange.BREAK` or `ScriptConfigChange.UNSURE`.
+        Type of change of the command line. Can be one of ``ScriptConfigChange.NOEFFET``,
+        ``ScriptConfigChange.BREAK`` or ``ScriptConfigChange.UNSURE``.
 
     """
 
@@ -787,8 +807,8 @@ class ScriptConfigChange(BaseAdapter):
         Parameters
         ----------
         change_type: `str`
-            Type of change of the script's config. Can be one of `ScriptConfigChange.NOEFFET`,
-            `ScriptConfigChange.BREAK` or `ScriptConfigChange.UNSURE`.
+            Type of change of the script's config. Can be one of ``ScriptConfigChange.NOEFFET``,
+            ``ScriptConfigChange.BREAK`` or ``ScriptConfigChange.UNSURE``.
 
         """
         self.validate(change_type)
@@ -798,15 +818,17 @@ class ScriptConfigChange(BaseAdapter):
     def validate(cls, change_type):
         """Validate change type and raise ValueError if invalid"""
         if change_type not in cls.types:
-            raise ValueError("Invalid script's config change type '%s'. Should be one of %s" %
-                             (change_type, str(cls.types)))
+            raise ValueError(
+                "Invalid script's config change type '%s'. Should be one of %s"
+                % (change_type, str(cls.types))
+            )
 
     def forward(self, trials):
         """Filter out parent's trials if type of script's config change is BREAK.
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.forward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
         """
         if self.change_type == self.BREAK:
             return []
@@ -818,7 +840,7 @@ class ScriptConfigChange(BaseAdapter):
 
         .. seealso::
 
-            :meth:`orion.core.evc.BaseAdapter.backward`
+            :meth:`orion.core.evc.adapters.BaseAdapter.backward`
         """
         if self.change_type in [self.BREAK, self.UNSURE]:
             return []
@@ -833,8 +855,46 @@ class ScriptConfigChange(BaseAdapter):
             :meth:`orion.core.evc.adapters.BaseAdapter.to_dict`
         """
         ret = dict(
-            of_type=self.__class__.__name__.lower(),
-            change_type=self.change_type)
+            of_type=self.__class__.__name__.lower(), change_type=self.change_type
+        )
+        return ret
+
+
+class OrionVersionChange(BaseAdapter):
+    """Adapter for changes of Oríon version
+
+    .. note::
+
+        Does nothing...
+
+    """
+
+    def forward(self, trials):
+        """Pass all trials from parent experiment to child experiment
+
+        .. seealso::
+
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
+        """
+        return trials
+
+    def backward(self, trials):
+        """Pass all trials from child experiment to parent experiment
+
+        .. seealso::
+
+            :meth:`orion.core.evc.adapters.BaseAdapter.forward`
+        """
+        return trials
+
+    def to_dict(self):
+        """Provide the configuration of the adapter as a dictionary
+
+        .. seealso::
+
+            :meth:`orion.core.evc.adapters.BaseAdapter.to_dict`
+        """
+        ret = dict(of_type=self.__class__.__name__.lower())
         return ret
 
 
