@@ -19,11 +19,37 @@ from orion.core.io.database.mongodb import MongoDB
 from orion.core.io.database.pickleddb import PickledDB
 from orion.core.utils.singleton import update_singletons
 from orion.core.worker.trial import Trial
-from orion.storage.base import Storage
+from orion.storage.base import Storage, get_storage, setup_storage
 from orion.storage.legacy import Legacy
 from orion.testing import OrionState
 
 
+def pytest_addoption(parser):
+    parser.addoption(
+        "--mongodb",
+        action="store_true",
+        default=False,
+        help="Include MongoDB tests and exclude non-MongoDB databases tests. "
+        "Default behaviour includes non-MongoDB tests and excludes MongoDB "
+        "databases tests.",
+    )
+
+
+def pytest_configure(config):
+    config.addinivalue_line(
+        "markers",
+        "db_types_only(db_types): mark test to run only with listed database types",
+    )
+    config.addinivalue_line(
+        "markers",
+        "drop_collections(collections): mark test to drop collections prior running",
+    )
+    config.addinivalue_line(
+        "markers",
+        "insert_collections(collections): mark test to insert collections prior running",
+    )
+
+
 @pytest.fixture(scope="session", autouse=True)
 def shield_from_user_config(request):
     """Do not read user's yaml global config."""
@@ -315,24 +341,6 @@ def version_XYZ(monkeypatch):
     monkeypatch.setattr(resolve_config, "update_metadata", update_metadata)
 
 
-@pytest.fixture()
-def create_db_instance(null_db_instances, clean_db):
-    """Create and save a singleton database instance."""
-    try:
-        database = {
-            "type": "MongoDB",
-            "name": "orion_test",
-            "username": "user",
-            "password": "pass",
-        }
-        db = Storage(of_type="legacy", database=database)
-    except ValueError:
-        db = Storage()
-
-    db = db._db
-    return db
-
-
 @pytest.fixture()
 def script_path():
     """Return a script path for mock"""
@@ -372,6 +380,12 @@ def setup_pickleddb_database():
     del os.environ["ORION_DB_ADDRESS"]
 
 
+@pytest.fixture(scope="function")
+def storage(setup_pickleddb_database):
+    setup_storage()
+    yield get_storage()
+
+
 @pytest.fixture()
 def with_user_userxyz(monkeypatch):
     """Make ``getpass.getuser()`` return ``'userxyz'``."""
