@@ -18,7 +18,7 @@ def execute(command, assert_code=0):
 
 
 @pytest.fixture
-def init_full_x(create_db_instance, monkeypatch):
+def init_full_x(setup_pickleddb_database, monkeypatch):
     """Init original experiment"""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     name = "full_x"
@@ -984,7 +984,9 @@ def test_auto_resolution_with_fidelity(init_full_x_full_y, monkeypatch):
     ]
 
 
-def test_init_w_version_from_parent_w_children(create_db_instance, monkeypatch, capsys):
+def test_init_w_version_from_parent_w_children(
+    setup_pickleddb_database, monkeypatch, capsys
+):
     """Test that init of experiment from version with children fails."""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     execute(
@@ -1007,7 +1009,7 @@ def test_init_w_version_from_parent_w_children(create_db_instance, monkeypatch,
     assert "Experiment name" in captured.err
 
 
-def test_init_w_version_from_exp_wout_child(create_db_instance, monkeypatch):
+def test_init_w_version_from_exp_wout_child(setup_pickleddb_database, monkeypatch):
     """Test that init of experiment from version without child works."""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     execute(
@@ -1026,7 +1028,7 @@ def test_init_w_version_from_exp_wout_child(create_db_instance, monkeypatch):
     assert len(list(exp))
 
 
-def test_init_w_version_gt_max(create_db_instance, monkeypatch):
+def test_init_w_version_gt_max(setup_pickleddb_database, monkeypatch):
     """Test that init of experiment from version higher than max works."""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     execute(
@@ -1045,7 +1047,7 @@ def test_init_w_version_gt_max(create_db_instance, monkeypatch):
     assert len(list(exp))
 
 
-def test_init_check_increment_w_children(create_db_instance, monkeypatch):
+def test_init_check_increment_w_children(setup_pickleddb_database, monkeypatch):
     """Test that incrementing version works with not same-named children."""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     execute(
@@ -1064,7 +1066,7 @@ def test_init_check_increment_w_children(create_db_instance, monkeypatch):
     assert len(list(exp))
 
 
-def test_branch_from_selected_version(create_db_instance, monkeypatch):
+def test_branch_from_selected_version(setup_pickleddb_database, monkeypatch):
     """Test that branching from a version passed with `--version` works."""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     execute(
