@@ -14,9 +14,7 @@ def get_user_corneau():
     return "corneau"
 
 
-@pytest.mark.usefixtures("clean_db")
-@pytest.mark.usefixtures("null_db_instances")
-def test_insert_invalid_experiment(database, monkeypatch, capsys):
+def test_insert_invalid_experiment(storage, monkeypatch, capsys):
     """Test the insertion of an invalid experiment"""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     monkeypatch.setattr("getpass.getuser", get_user_corneau)
@@ -40,8 +38,8 @@ def test_insert_invalid_experiment(database, monkeypatch, capsys):
     assert "Error: No experiment with given name 'dumb_experiment'"
 
 
-@pytest.mark.usefixtures("only_experiments_db", "null_db_instances", "version_XYZ")
-def test_insert_single_trial(database, monkeypatch, script_path):
+@pytest.mark.usefixtures("only_experiments_db", "version_XYZ")
+def test_insert_single_trial(storage, monkeypatch, script_path):
     """Try to insert a single trial"""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     monkeypatch.setattr("getpass.getuser", get_user_corneau)
@@ -58,24 +56,24 @@ def test_insert_single_trial(database, monkeypatch, script_path):
         ]
     )
 
-    exp = list(database.experiments.find({"name": "test_insert_normal"}))
+    exp = list(storage.fetch_experiments({"name": "test_insert_normal"}))
 
     assert len(exp) == 1
     exp = exp[0]
     assert "_id" in exp
 
-    trials = list(database.trials.find({"experiment": exp["_id"]}))
+    trials = list(storage.fetch_trials(uid=exp["_id"]))
 
     assert len(trials) == 1
 
     trial = trials[0]
 
-    assert trial["status"] == "new"
-    assert trial["params"][0]["value"] == 1
+    assert trial.status == "new"
+    assert trial.params["/x"] == 1
 
 
-@pytest.mark.usefixtures("only_experiments_db", "null_db_instances", "version_XYZ")
-def test_insert_single_trial_default_value(database, monkeypatch):
+@pytest.mark.usefixtures("only_experiments_db", "version_XYZ")
+def test_insert_single_trial_default_value(storage, monkeypatch):
     """Try to insert a single trial using a default value"""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     monkeypatch.setattr("getpass.getuser", get_user_corneau)
@@ -91,24 +89,23 @@ def test_insert_single_trial_default_value(database, monkeypatch):
         ]
     )
 
-    exp = list(database.experiments.find({"name": "test_insert_normal"}))
+    exp = list(storage.fetch_experiments({"name": "test_insert_normal"}))
     assert len(exp) == 1
     exp = exp[0]
     assert "_id" in exp
 
-    trials = list(database.trials.find({"experiment": exp["_id"]}))
+    trials = list(storage.fetch_trials(uid=exp["_id"]))
 
     assert len(trials) == 1
 
     trial = trials[0]
 
-    assert trial["status"] == "new"
-    assert trial["params"][0]["value"] == 1
+    assert trial.status == "new"
+    assert trial.params["/x"] == 1
 
 
 @pytest.mark.usefixtures("only_experiments_db")
-@pytest.mark.usefixtures("null_db_instances")
-def test_insert_with_no_default_value(database, monkeypatch):
+def test_insert_with_no_default_value(monkeypatch):
     """Try to insert a single trial by omitting a namespace with no default value"""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     monkeypatch.setattr("getpass.getuser", get_user_corneau)
@@ -129,8 +126,7 @@ def test_insert_with_no_default_value(database, monkeypatch):
 
 
 @pytest.mark.usefixtures("only_experiments_db")
-@pytest.mark.usefixtures("null_db_instances")
-def test_insert_with_incorrect_namespace(database, monkeypatch):
+def test_insert_with_incorrect_namespace(monkeypatch):
     """Try to insert a single trial with a namespace not inside the experiment space"""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     monkeypatch.setattr("getpass.getuser", get_user_corneau)
@@ -152,8 +148,7 @@ def test_insert_with_incorrect_namespace(database, monkeypatch):
 
 
 @pytest.mark.usefixtures("only_experiments_db")
-@pytest.mark.usefixtures("null_db_instances")
-def test_insert_with_outside_bound_value(database, monkeypatch):
+def test_insert_with_outside_bound_value(monkeypatch):
     """Try to insert a single trial with value outside the distribution's interval"""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     monkeypatch.setattr("getpass.getuser", get_user_corneau)
@@ -174,8 +169,8 @@ def test_insert_with_outside_bound_value(database, monkeypatch):
     assert "Value 100 is outside of" in str(exc_info.value)
 
 
-@pytest.mark.usefixtures("only_experiments_db", "null_db_instances", "version_XYZ")
-def test_insert_two_hyperparameters(database, monkeypatch):
+@pytest.mark.usefixtures("only_experiments_db", "version_XYZ")
+def test_insert_two_hyperparameters(storage, monkeypatch):
     """Try to insert a single trial with two hyperparameters"""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     monkeypatch.setattr("getpass.getuser", get_user_corneau)
@@ -192,24 +187,23 @@ def test_insert_two_hyperparameters(database, monkeypatch):
         ]
     )
 
-    exp = list(database.experiments.find({"name": "test_insert_two_hyperparameters"}))
+    exp = list(storage.fetch_experiments({"name": "test_insert_two_hyperparameters"}))
     assert len(exp) == 1
     exp = exp[0]
     assert "_id" in exp
 
-    trials = list(database.trials.find({"experiment": exp["_id"]}))
+    trials = list(storage.fetch_trials(uid=exp["_id"]))
 
     assert len(trials) == 1
 
     trial = trials[0]
 
-    assert trial["status"] == "new"
-    assert trial["params"][0]["value"] == 1
-    assert trial["params"][1]["value"] == 2
+    assert trial.status == "new"
+    assert trial.params["/x"] == 1
+    assert trial.params["/y"] == 2
 
 
-@pytest.mark.usefixtures("clean_db")
-def test_insert_with_version(create_db_instance, monkeypatch, script_path):
+def test_insert_with_version(storage, monkeypatch, script_path):
     """Try to insert a single trial inside a specific version"""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     orion.core.cli.main(
@@ -238,12 +232,12 @@ def test_insert_with_version(create_db_instance, monkeypatch, script_path):
         ]
     )
 
-    exp = list(get_storage().fetch_experiments({"name": "experiment", "version": 1}))
+    exp = list(storage.fetch_experiments({"name": "experiment", "version": 1}))
     assert len(exp) == 1
     exp = exp[0]
     assert "_id" in exp
 
-    trials = list(get_storage().fetch_trials(uid=exp["_id"]))
+    trials = list(storage.fetch_trials(uid=exp["_id"]))
     assert len(trials) == 0
 
     orion.core.cli.main(
@@ -260,7 +254,7 @@ def test_insert_with_version(create_db_instance, monkeypatch, script_path):
         ]
     )
 
-    trials = list(get_storage().fetch_trials(uid=exp["_id"]))
+    trials = list(storage.fetch_trials(uid=exp["_id"]))
 
     assert len(trials) == 1
 
