@@ -8,7 +8,7 @@ import pytest
 import orion.core.cli
 
 
-def test_no_experiments(clean_db, monkeypatch, capsys):
+def test_no_experiments(setup_pickleddb_database, monkeypatch, capsys):
     """Test status with no experiments."""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     orion.core.cli.main(["status"])
@@ -18,7 +18,7 @@ def test_no_experiments(clean_db, monkeypatch, capsys):
     assert captured == "No experiment found\n"
 
 
-def test_no_version_backward_compatible(clean_db, one_experiment_no_version, capsys):
+def test_no_version_backward_compatible(one_experiment_no_version, capsys):
     """Test status with no experiments."""
     orion.core.cli.main(["status"])
 
@@ -34,7 +34,7 @@ empty
     assert captured == expected
 
 
-def test_python_api(clean_db, with_experiment_using_python_api, capsys):
+def test_python_api(with_experiment_using_python_api, capsys):
     """Test status with experiments built using python api."""
     orion.core.cli.main(["status"])
 
@@ -55,7 +55,7 @@ empty
     assert captured == expected
 
 
-def test_missing_conf_file(clean_db, with_experiment_missing_conf_file, capsys):
+def test_missing_conf_file(with_experiment_missing_conf_file, capsys):
     """Test status can handle experiments when the user script config file is missing"""
     orion.core.cli.main(["status"])
 
@@ -71,7 +71,7 @@ empty
     assert captured == expected
 
 
-def test_experiment_without_trials_wout_ac(clean_db, one_experiment, capsys):
+def test_experiment_without_trials_wout_ac(one_experiment, capsys):
     """Test status with only one experiment and no trials."""
     orion.core.cli.main(["status"])
 
@@ -87,7 +87,7 @@ empty
     assert captured == expected
 
 
-def test_experiment_wout_success_wout_ac(clean_db, single_without_success, capsys):
+def test_experiment_wout_success_wout_ac(single_without_success, capsys):
     """Test status with only one experiment and no successful trial."""
     orion.core.cli.main(["status"])
 
@@ -109,7 +109,7 @@ suspended             1
     assert captured == expected
 
 
-def test_experiment_number_same_list_status(clean_db, single_without_success, capsys):
+def test_experiment_number_same_list_status(single_without_success, capsys):
     """Test status and list command output the consistent number of experiments"""
     orion.core.cli.main(["status"])
 
@@ -137,7 +137,7 @@ suspended             1
     assert captured == " test_single_exp-v1\n"
 
 
-def test_experiment_w_trials_wout_ac(clean_db, single_with_trials, capsys):
+def test_experiment_w_trials_wout_ac(single_with_trials, capsys):
     """Test status with only one experiment and all trials."""
     orion.core.cli.main(["status"])
 
@@ -160,7 +160,7 @@ suspended             1
     assert captured == expected
 
 
-def test_two_unrelated_w_trials_wout_ac(clean_db, unrelated_with_trials, capsys):
+def test_two_unrelated_w_trials_wout_ac(unrelated_with_trials, capsys):
     """Test two unrelated experiments, with all types of trials."""
     orion.core.cli.main(["status"])
 
@@ -196,7 +196,7 @@ suspended             1
     assert captured == expected
 
 
-def test_two_related_w_trials_wout_ac(clean_db, family_with_trials, capsys):
+def test_two_related_w_trials_wout_ac(family_with_trials, capsys):
     """Test two related experiments, with all types of trials."""
     orion.core.cli.main(["status"])
 
@@ -232,7 +232,7 @@ suspended             1
     assert captured == expected
 
 
-def test_three_unrelated_wout_ac(clean_db, three_experiments_with_trials, capsys):
+def test_three_unrelated_wout_ac(three_experiments_with_trials, capsys):
     """Test three unrelated experiments with all types of trials."""
     orion.core.cli.main(["status"])
 
@@ -280,7 +280,7 @@ suspended             1
     assert captured == expected
 
 
-def test_three_related_wout_ac(clean_db, three_family_with_trials, capsys):
+def test_three_related_wout_ac(three_family_with_trials, capsys):
     """Test three related experiments with all types of trials."""
     orion.core.cli.main(["status"])
 
@@ -328,9 +328,7 @@ suspended             1
     assert captured == expected
 
 
-def test_three_related_branch_wout_ac(
-    clean_db, three_family_branch_with_trials, capsys
-):
+def test_three_related_branch_wout_ac(three_family_branch_with_trials, capsys):
     """Test three related experiments with all types of trials."""
     orion.core.cli.main(["status"])
 
@@ -378,7 +376,7 @@ suspended             1
     assert captured == expected
 
 
-def test_one_wout_trials_w_a_wout_c(clean_db, one_experiment, capsys):
+def test_one_wout_trials_w_a_wout_c(one_experiment, capsys):
     """Test experiments, without trials, with --all."""
     orion.core.cli.main(["status", "--all"])
 
@@ -397,7 +395,7 @@ empty
     assert captured == expected
 
 
-def test_one_w_trials_w_a_wout_c(clean_db, single_with_trials, capsys):
+def test_one_w_trials_w_a_wout_c(single_with_trials, capsys):
     """Test experiment, with all trials, with --all."""
     orion.core.cli.main(["status", "--all"])
 
@@ -408,12 +406,12 @@ test_single_exp-v1
 ==================
 id                                status         min obj
 --------------------------------  -----------  ---------
-9f360d1b4eb2707f19dd619d0d898dd9  broken
-47564e5e390348b9d1335d4013895eb4  completed            0
-aefd38473f108016fd4842aa855732ff  interrupted
-0695f63ecaf7d78f4b85d4cb344e0dc0  new
-b0ea9850c09370215b45b81edd33c7d3  reserved
-b49e902aebccce14e834d96e411f896e  suspended
+6c10cf8f7a065c9f0bb0290800ce2926  broken
+d8a550d66949a115d3db3925bd93829c  completed            0
+ad2f2049de1fe1a600cde6d118588461  interrupted
+9cc0d5701543d6eff7a7cd95dd0681b9  new
+3de6f76692d763e3ccb1422172cccc1d  reserved
+1a9fc30e1bd96b26e086196112f31a69  suspended
 
 
 """
@@ -421,7 +419,7 @@ b49e902aebccce14e834d96e411f896e  suspended
     assert captured == expected
 
 
-def test_one_wout_success_w_a_wout_c(clean_db, single_without_success, capsys):
+def test_one_wout_success_w_a_wout_c(single_without_success, capsys):
     """Test experiment, without success, with --all."""
     orion.core.cli.main(["status", "--all"])
 
@@ -432,11 +430,11 @@ test_single_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-9f360d1b4eb2707f19dd619d0d898dd9  broken
-aefd38473f108016fd4842aa855732ff  interrupted
-0695f63ecaf7d78f4b85d4cb344e0dc0  new
-b0ea9850c09370215b45b81edd33c7d3  reserved
-b49e902aebccce14e834d96e411f896e  suspended
+6c10cf8f7a065c9f0bb0290800ce2926  broken
+ad2f2049de1fe1a600cde6d118588461  interrupted
+9cc0d5701543d6eff7a7cd95dd0681b9  new
+3de6f76692d763e3ccb1422172cccc1d  reserved
+1a9fc30e1bd96b26e086196112f31a69  suspended
 
 
 """
@@ -444,7 +442,7 @@ b49e902aebccce14e834d96e411f896e  suspended
     assert captured == expected
 
 
-def test_two_unrelated_w_a_wout_c(clean_db, unrelated_with_trials, capsys):
+def test_two_unrelated_w_a_wout_c(unrelated_with_trials, capsys):
     """Test two unrelated experiments with --all."""
     orion.core.cli.main(["status", "--all"])
 
@@ -455,24 +453,24 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-c2187f4954884c801e423d851aec9a0b  broken
-e42cc22a15188d72df315b9eac79c9c0  completed
-b849f69cc3a77f39382d7435d0d41b14  interrupted
-7fbbd152f7ca2c064bf00441e311609d  new
-667513aa2cb2244bee9c4f41c7ff1cea  reserved
-557b9fdb9f96569dff7eb2de10d3946f  suspended
+259021a55c2a5af7074a41ed6639b2f3  broken
+cbb766d729294f77f0ca86ff2bf72707  completed
+ca6576848f17201852225d816fb71fcc  interrupted
+28097ba31dbdffc0aa265c6bc5c98b0f  new
+adbe6c400cd1e667696e28fbecd000a0  reserved
+5679af6c6bb54aa8042043008ab2bc1f  suspended
 
 
 test_single_exp-v1
 ==================
 id                                status         min obj
 --------------------------------  -----------  ---------
-9f360d1b4eb2707f19dd619d0d898dd9  broken
-47564e5e390348b9d1335d4013895eb4  completed            0
-aefd38473f108016fd4842aa855732ff  interrupted
-0695f63ecaf7d78f4b85d4cb344e0dc0  new
-b0ea9850c09370215b45b81edd33c7d3  reserved
-b49e902aebccce14e834d96e411f896e  suspended
+6c10cf8f7a065c9f0bb0290800ce2926  broken
+d8a550d66949a115d3db3925bd93829c  completed            0
+ad2f2049de1fe1a600cde6d118588461  interrupted
+9cc0d5701543d6eff7a7cd95dd0681b9  new
+3de6f76692d763e3ccb1422172cccc1d  reserved
+1a9fc30e1bd96b26e086196112f31a69  suspended
 
 
 """
@@ -480,7 +478,7 @@ b49e902aebccce14e834d96e411f896e  suspended
     assert captured == expected
 
 
-def test_two_related_w_a_wout_c(clean_db, family_with_trials, capsys):
+def test_two_related_w_a_wout_c(family_with_trials, capsys):
     """Test two related experiments with --all."""
     orion.core.cli.main(["status", "--all"])
 
@@ -491,24 +489,24 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-c2187f4954884c801e423d851aec9a0b  broken
-e42cc22a15188d72df315b9eac79c9c0  completed
-b849f69cc3a77f39382d7435d0d41b14  interrupted
-7fbbd152f7ca2c064bf00441e311609d  new
-667513aa2cb2244bee9c4f41c7ff1cea  reserved
-557b9fdb9f96569dff7eb2de10d3946f  suspended
+259021a55c2a5af7074a41ed6639b2f3  broken
+cbb766d729294f77f0ca86ff2bf72707  completed
+ca6576848f17201852225d816fb71fcc  interrupted
+28097ba31dbdffc0aa265c6bc5c98b0f  new
+adbe6c400cd1e667696e28fbecd000a0  reserved
+5679af6c6bb54aa8042043008ab2bc1f  suspended
 
 
   test_double_exp_child-v1
   ========================
   id                                status
   --------------------------------  -----------
-  9bd1ebc475bcb9e077a9e81a7c954a65  broken
-  3c1af2af2c8dc9862df2cef0a65d6e1f  completed
-  614ec3fc127d52129bc9d66d9aeec36c  interrupted
-  4487e7fc87c288d254f94dfa82cd79cc  new
-  7877287c718d7844570003fd654f66ba  reserved
-  ff997e666e20c5a8c1a816dde0b5e2e9  suspended
+  890b4f07685ed020f5d9e28cac9316e1  broken
+  ff81ff46da5ffe6bd623fb38a06df993  completed
+  78a3e60699eee1d0b9bc51a049168fce  interrupted
+  13cd454155748351790525e3079fb620  new
+  d1b7ecbd3621de9195a42c76defb6603  reserved
+  33d6208ef03cb236a8f3b567665c357d  suspended
 
 
 """
@@ -516,7 +514,7 @@ b849f69cc3a77f39382d7435d0d41b14  interrupted
     assert captured == expected
 
 
-def test_three_unrelated_w_a_wout_c(clean_db, three_experiments_with_trials, capsys):
+def test_three_unrelated_w_a_wout_c(three_experiments_with_trials, capsys):
     """Test three unrelated experiments with --all."""
     orion.core.cli.main(["status", "--all"])
 
@@ -527,36 +525,36 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-c2187f4954884c801e423d851aec9a0b  broken
-e42cc22a15188d72df315b9eac79c9c0  completed
-b849f69cc3a77f39382d7435d0d41b14  interrupted
-7fbbd152f7ca2c064bf00441e311609d  new
-667513aa2cb2244bee9c4f41c7ff1cea  reserved
-557b9fdb9f96569dff7eb2de10d3946f  suspended
+259021a55c2a5af7074a41ed6639b2f3  broken
+cbb766d729294f77f0ca86ff2bf72707  completed
+ca6576848f17201852225d816fb71fcc  interrupted
+28097ba31dbdffc0aa265c6bc5c98b0f  new
+adbe6c400cd1e667696e28fbecd000a0  reserved
+5679af6c6bb54aa8042043008ab2bc1f  suspended
 
 
   test_double_exp_child-v1
   ========================
   id                                status
   --------------------------------  -----------
-  9bd1ebc475bcb9e077a9e81a7c954a65  broken
-  3c1af2af2c8dc9862df2cef0a65d6e1f  completed
-  614ec3fc127d52129bc9d66d9aeec36c  interrupted
-  4487e7fc87c288d254f94dfa82cd79cc  new
-  7877287c718d7844570003fd654f66ba  reserved
-  ff997e666e20c5a8c1a816dde0b5e2e9  suspended
+  890b4f07685ed020f5d9e28cac9316e1  broken
+  ff81ff46da5ffe6bd623fb38a06df993  completed
+  78a3e60699eee1d0b9bc51a049168fce  interrupted
+  13cd454155748351790525e3079fb620  new
+  d1b7ecbd3621de9195a42c76defb6603  reserved
+  33d6208ef03cb236a8f3b567665c357d  suspended
 
 
 test_single_exp-v1
 ==================
 id                                status         min obj
 --------------------------------  -----------  ---------
-9f360d1b4eb2707f19dd619d0d898dd9  broken
-47564e5e390348b9d1335d4013895eb4  completed            0
-aefd38473f108016fd4842aa855732ff  interrupted
-0695f63ecaf7d78f4b85d4cb344e0dc0  new
-b0ea9850c09370215b45b81edd33c7d3  reserved
-b49e902aebccce14e834d96e411f896e  suspended
+6c10cf8f7a065c9f0bb0290800ce2926  broken
+d8a550d66949a115d3db3925bd93829c  completed            0
+ad2f2049de1fe1a600cde6d118588461  interrupted
+9cc0d5701543d6eff7a7cd95dd0681b9  new
+3de6f76692d763e3ccb1422172cccc1d  reserved
+1a9fc30e1bd96b26e086196112f31a69  suspended
 
 
 """
@@ -564,7 +562,7 @@ b49e902aebccce14e834d96e411f896e  suspended
     assert captured == expected
 
 
-def test_three_related_w_a_wout_c(clean_db, three_family_with_trials, capsys):
+def test_three_related_w_a_wout_c(three_family_with_trials, capsys):
     """Test three related experiments with --all."""
     orion.core.cli.main(["status", "--all"])
 
@@ -575,36 +573,36 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-c2187f4954884c801e423d851aec9a0b  broken
-e42cc22a15188d72df315b9eac79c9c0  completed
-b849f69cc3a77f39382d7435d0d41b14  interrupted
-7fbbd152f7ca2c064bf00441e311609d  new
-667513aa2cb2244bee9c4f41c7ff1cea  reserved
-557b9fdb9f96569dff7eb2de10d3946f  suspended
+259021a55c2a5af7074a41ed6639b2f3  broken
+cbb766d729294f77f0ca86ff2bf72707  completed
+ca6576848f17201852225d816fb71fcc  interrupted
+28097ba31dbdffc0aa265c6bc5c98b0f  new
+adbe6c400cd1e667696e28fbecd000a0  reserved
+5679af6c6bb54aa8042043008ab2bc1f  suspended
 
 
   test_double_exp_child-v1
   ========================
   id                                status
   --------------------------------  -----------
-  9bd1ebc475bcb9e077a9e81a7c954a65  broken
-  3c1af2af2c8dc9862df2cef0a65d6e1f  completed
-  614ec3fc127d52129bc9d66d9aeec36c  interrupted
-  4487e7fc87c288d254f94dfa82cd79cc  new
-  7877287c718d7844570003fd654f66ba  reserved
-  ff997e666e20c5a8c1a816dde0b5e2e9  suspended
+  890b4f07685ed020f5d9e28cac9316e1  broken
+  ff81ff46da5ffe6bd623fb38a06df993  completed
+  78a3e60699eee1d0b9bc51a049168fce  interrupted
+  13cd454155748351790525e3079fb620  new
+  d1b7ecbd3621de9195a42c76defb6603  reserved
+  33d6208ef03cb236a8f3b567665c357d  suspended
 
 
   test_double_exp_child2-v1
   =========================
   id                                status
   --------------------------------  -----------
-  2c2b64df1859b45a0b01362ca146584a  broken
-  225b4a17dd29d5c0423a81c1ddda8f0e  completed
-  fb0bb45bd0a45225e2368a8158df0427  interrupted
-  57bd3071c7c1c39ceb997a7b37c5470d  new
-  673449a3910fdea777ac8cb8576cdbe3  reserved
-  01a38cce74701c3b40eb3d92143bc90f  suspended
+  1c238040d6b6d8423d99a08551fe0998  broken
+  2c13424a9212ab92ea592bdaeb1c13e9  completed
+  a2680fbda1faa9dfb94946cf25536f44  interrupted
+  abbda454d0577ded5b8e784a9d6d5abb  new
+  df58aa8fd875f129f7faa84eb15ca453  reserved
+  71657e86bad0f2e8b06098a64cb883b6  suspended
 
 
 """
@@ -612,9 +610,7 @@ b849f69cc3a77f39382d7435d0d41b14  interrupted
     assert captured == expected
 
 
-def test_three_related_branch_w_a_wout_c(
-    clean_db, three_family_branch_with_trials, capsys
-):
+def test_three_related_branch_w_a_wout_c(three_family_branch_with_trials, capsys):
     """Test three related experiments in a branch with --all."""
     orion.core.cli.main(["status", "--all"])
 
@@ -625,36 +621,36 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-c2187f4954884c801e423d851aec9a0b  broken
-e42cc22a15188d72df315b9eac79c9c0  completed
-b849f69cc3a77f39382d7435d0d41b14  interrupted
-7fbbd152f7ca2c064bf00441e311609d  new
-667513aa2cb2244bee9c4f41c7ff1cea  reserved
-557b9fdb9f96569dff7eb2de10d3946f  suspended
+259021a55c2a5af7074a41ed6639b2f3  broken
+cbb766d729294f77f0ca86ff2bf72707  completed
+ca6576848f17201852225d816fb71fcc  interrupted
+28097ba31dbdffc0aa265c6bc5c98b0f  new
+adbe6c400cd1e667696e28fbecd000a0  reserved
+5679af6c6bb54aa8042043008ab2bc1f  suspended
 
 
   test_double_exp_child-v1
   ========================
   id                                status
   --------------------------------  -----------
-  9bd1ebc475bcb9e077a9e81a7c954a65  broken
-  3c1af2af2c8dc9862df2cef0a65d6e1f  completed
-  614ec3fc127d52129bc9d66d9aeec36c  interrupted
-  4487e7fc87c288d254f94dfa82cd79cc  new
-  7877287c718d7844570003fd654f66ba  reserved
-  ff997e666e20c5a8c1a816dde0b5e2e9  suspended
+  890b4f07685ed020f5d9e28cac9316e1  broken
+  ff81ff46da5ffe6bd623fb38a06df993  completed
+  78a3e60699eee1d0b9bc51a049168fce  interrupted
+  13cd454155748351790525e3079fb620  new
+  d1b7ecbd3621de9195a42c76defb6603  reserved
+  33d6208ef03cb236a8f3b567665c357d  suspended
 
 
     test_double_exp_grand_child-v1
     ==============================
     id                                status
     --------------------------------  -----------
-    82f82a325b7cf09251a34c9264e1812a  broken
-    94baf74a4e94f800b6865d8ab5675428  completed
-    e24b2e542c0869064abdb20c2de250eb  interrupted
-    960bad983c3ee6349b8767fe452ecbb3  new
-    8d8578e31c740c1c0fc385c961702481  reserved
-    584375e2b32af0573f4692cb47a2ec99  suspended
+    e374d8f802aed52c07763545f46228a7  broken
+    f9ee14ff9ef0b95ed7a24860731c85a9  completed
+    3f7dff101490727d5fa0efeb36ca6366  interrupted
+    40838d46dbf7778a3cb51b7a09118391  new
+    b7860a18b2700cce4e8009cde543975c  reserved
+    cd406126bc350ad82ac77c75174cc8a2  suspended
 
 
 """
@@ -662,7 +658,7 @@ b849f69cc3a77f39382d7435d0d41b14  interrupted
     assert captured == expected
 
 
-def test_two_unrelated_w_c_wout_a(clean_db, unrelated_with_trials, capsys):
+def test_two_unrelated_w_c_wout_a(unrelated_with_trials, capsys):
     """Test two unrelated experiments with --collapse."""
     orion.core.cli.main(["status", "--collapse"])
 
@@ -698,7 +694,7 @@ suspended             1
     assert captured == expected
 
 
-def test_two_related_w_c_wout_a(clean_db, family_with_trials, capsys):
+def test_two_related_w_c_wout_a(family_with_trials, capsys):
     """Test two related experiments with --collapse."""
     orion.core.cli.main(["status", "--collapse"])
 
@@ -722,7 +718,7 @@ suspended             1
     assert captured == expected
 
 
-def test_three_unrelated_w_c_wout_a(clean_db, three_experiments_with_trials, capsys):
+def test_three_unrelated_w_c_wout_a(three_experiments_with_trials, capsys):
     """Test three unrelated experiments with --collapse."""
     orion.core.cli.main(["status", "--collapse"])
 
@@ -758,7 +754,7 @@ suspended             1
     assert captured == expected
 
 
-def test_three_related_w_c_wout_a(clean_db, three_family_with_trials, capsys):
+def test_three_related_w_c_wout_a(three_family_with_trials, capsys):
     """Test three related experiments with --collapse."""
     orion.core.cli.main(["status", "--collapse"])
 
@@ -782,9 +778,7 @@ suspended             1
     assert captured == expected
 
 
-def test_three_related_branch_w_c_wout_a(
-    clean_db, three_family_branch_with_trials, capsys
-):
+def test_three_related_branch_w_c_wout_a(three_family_branch_with_trials, capsys):
     """Test three related experiments with --collapse."""
     orion.core.cli.main(["status", "--collapse"])
 
@@ -808,7 +802,7 @@ suspended             1
     assert captured == expected
 
 
-def test_two_unrelated_w_ac(clean_db, unrelated_with_trials, capsys):
+def test_two_unrelated_w_ac(unrelated_with_trials, capsys):
     """Test two unrelated experiments with --collapse and --all."""
     orion.core.cli.main(["status", "--collapse", "--all"])
 
@@ -819,24 +813,24 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-c2187f4954884c801e423d851aec9a0b  broken
-e42cc22a15188d72df315b9eac79c9c0  completed
-b849f69cc3a77f39382d7435d0d41b14  interrupted
-7fbbd152f7ca2c064bf00441e311609d  new
-667513aa2cb2244bee9c4f41c7ff1cea  reserved
-557b9fdb9f96569dff7eb2de10d3946f  suspended
+259021a55c2a5af7074a41ed6639b2f3  broken
+cbb766d729294f77f0ca86ff2bf72707  completed
+ca6576848f17201852225d816fb71fcc  interrupted
+28097ba31dbdffc0aa265c6bc5c98b0f  new
+adbe6c400cd1e667696e28fbecd000a0  reserved
+5679af6c6bb54aa8042043008ab2bc1f  suspended
 
 
 test_single_exp-v1
 ==================
 id                                status         min obj
 --------------------------------  -----------  ---------
-9f360d1b4eb2707f19dd619d0d898dd9  broken
-47564e5e390348b9d1335d4013895eb4  completed            0
-aefd38473f108016fd4842aa855732ff  interrupted
-0695f63ecaf7d78f4b85d4cb344e0dc0  new
-b0ea9850c09370215b45b81edd33c7d3  reserved
-b49e902aebccce14e834d96e411f896e  suspended
+6c10cf8f7a065c9f0bb0290800ce2926  broken
+d8a550d66949a115d3db3925bd93829c  completed            0
+ad2f2049de1fe1a600cde6d118588461  interrupted
+9cc0d5701543d6eff7a7cd95dd0681b9  new
+3de6f76692d763e3ccb1422172cccc1d  reserved
+1a9fc30e1bd96b26e086196112f31a69  suspended
 
 
 """
@@ -844,7 +838,7 @@ b49e902aebccce14e834d96e411f896e  suspended
     assert captured == expected
 
 
-def test_two_related_w_ac(clean_db, family_with_trials, capsys):
+def test_two_related_w_ac(family_with_trials, capsys):
     """Test two related experiments with --collapse and --all."""
     orion.core.cli.main(["status", "--collapse", "--all"])
 
@@ -855,13 +849,13 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-c2187f4954884c801e423d851aec9a0b  broken
-e42cc22a15188d72df315b9eac79c9c0  completed
-b849f69cc3a77f39382d7435d0d41b14  interrupted
-7fbbd152f7ca2c064bf00441e311609d  new
-d5f1c1cae188608b581ded20cd198679  new
-667513aa2cb2244bee9c4f41c7ff1cea  reserved
-557b9fdb9f96569dff7eb2de10d3946f  suspended
+259021a55c2a5af7074a41ed6639b2f3  broken
+cbb766d729294f77f0ca86ff2bf72707  completed
+ca6576848f17201852225d816fb71fcc  interrupted
+28097ba31dbdffc0aa265c6bc5c98b0f  new
+4c409da13bdc93c54f6997797c296356  new
+adbe6c400cd1e667696e28fbecd000a0  reserved
+5679af6c6bb54aa8042043008ab2bc1f  suspended
 
 
 """
@@ -869,7 +863,7 @@ d5f1c1cae188608b581ded20cd198679  new
     assert captured == expected
 
 
-def test_three_unrelated_w_ac(clean_db, three_experiments_with_trials, capsys):
+def test_three_unrelated_w_ac(three_experiments_with_trials, capsys):
     """Test three unrelated experiments with --collapse and --all."""
     orion.core.cli.main(["status", "--collapse", "--all"])
 
@@ -880,25 +874,25 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-c2187f4954884c801e423d851aec9a0b  broken
-e42cc22a15188d72df315b9eac79c9c0  completed
-b849f69cc3a77f39382d7435d0d41b14  interrupted
-7fbbd152f7ca2c064bf00441e311609d  new
-d5f1c1cae188608b581ded20cd198679  new
-667513aa2cb2244bee9c4f41c7ff1cea  reserved
-557b9fdb9f96569dff7eb2de10d3946f  suspended
+259021a55c2a5af7074a41ed6639b2f3  broken
+cbb766d729294f77f0ca86ff2bf72707  completed
+ca6576848f17201852225d816fb71fcc  interrupted
+28097ba31dbdffc0aa265c6bc5c98b0f  new
+4c409da13bdc93c54f6997797c296356  new
+adbe6c400cd1e667696e28fbecd000a0  reserved
+5679af6c6bb54aa8042043008ab2bc1f  suspended
 
 
 test_single_exp-v1
 ==================
 id                                status         min obj
 --------------------------------  -----------  ---------
-9f360d1b4eb2707f19dd619d0d898dd9  broken
-47564e5e390348b9d1335d4013895eb4  completed            0
-aefd38473f108016fd4842aa855732ff  interrupted
-0695f63ecaf7d78f4b85d4cb344e0dc0  new
-b0ea9850c09370215b45b81edd33c7d3  reserved
-b49e902aebccce14e834d96e411f896e  suspended
+6c10cf8f7a065c9f0bb0290800ce2926  broken
+d8a550d66949a115d3db3925bd93829c  completed            0
+ad2f2049de1fe1a600cde6d118588461  interrupted
+9cc0d5701543d6eff7a7cd95dd0681b9  new
+3de6f76692d763e3ccb1422172cccc1d  reserved
+1a9fc30e1bd96b26e086196112f31a69  suspended
 
 
 """
@@ -906,7 +900,7 @@ b49e902aebccce14e834d96e411f896e  suspended
     assert captured == expected
 
 
-def test_three_related_w_ac(clean_db, three_family_with_trials, capsys):
+def test_three_related_w_ac(three_family_with_trials, capsys):
     """Test three related experiments with --collapse and --all."""
     orion.core.cli.main(["status", "--collapse", "--all"])
 
@@ -917,14 +911,14 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-c2187f4954884c801e423d851aec9a0b  broken
-e42cc22a15188d72df315b9eac79c9c0  completed
-b849f69cc3a77f39382d7435d0d41b14  interrupted
-7fbbd152f7ca2c064bf00441e311609d  new
-d5f1c1cae188608b581ded20cd198679  new
-e5bf1dd6dec1a0c690ed62ff9146e5b8  new
-667513aa2cb2244bee9c4f41c7ff1cea  reserved
-557b9fdb9f96569dff7eb2de10d3946f  suspended
+259021a55c2a5af7074a41ed6639b2f3  broken
+cbb766d729294f77f0ca86ff2bf72707  completed
+ca6576848f17201852225d816fb71fcc  interrupted
+28097ba31dbdffc0aa265c6bc5c98b0f  new
+4c409da13bdc93c54f6997797c296356  new
+b97518f91e006cd4a2805657c596b11c  new
+adbe6c400cd1e667696e28fbecd000a0  reserved
+5679af6c6bb54aa8042043008ab2bc1f  suspended
 
 
 """
@@ -932,7 +926,7 @@ e5bf1dd6dec1a0c690ed62ff9146e5b8  new
     assert captured == expected
 
 
-def test_three_related_branch_w_ac(clean_db, three_family_branch_with_trials, capsys):
+def test_three_related_branch_w_ac(three_family_branch_with_trials, capsys):
     """Test three related experiments in a branch with --collapse and --all."""
     orion.core.cli.main(["status", "--collapse", "--all"])
 
@@ -943,14 +937,14 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-c2187f4954884c801e423d851aec9a0b  broken
-e42cc22a15188d72df315b9eac79c9c0  completed
-b849f69cc3a77f39382d7435d0d41b14  interrupted
-7fbbd152f7ca2c064bf00441e311609d  new
-d5f1c1cae188608b581ded20cd198679  new
-183148e187a1399989a06ffb02059920  new
-667513aa2cb2244bee9c4f41c7ff1cea  reserved
-557b9fdb9f96569dff7eb2de10d3946f  suspended
+259021a55c2a5af7074a41ed6639b2f3  broken
+cbb766d729294f77f0ca86ff2bf72707  completed
+ca6576848f17201852225d816fb71fcc  interrupted
+28097ba31dbdffc0aa265c6bc5c98b0f  new
+4c409da13bdc93c54f6997797c296356  new
+5183ee9c28601cc78c0a148a386df9f9  new
+adbe6c400cd1e667696e28fbecd000a0  reserved
+5679af6c6bb54aa8042043008ab2bc1f  suspended
 
 
 """
@@ -958,7 +952,7 @@ d5f1c1cae188608b581ded20cd198679  new
     assert captured == expected
 
 
-def test_no_experiments_w_name(clean_db, monkeypatch, capsys):
+def test_no_experiments_w_name(setup_pickleddb_database, monkeypatch, capsys):
     """Test status when --name <exp> does not exist."""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     orion.core.cli.main(["status", "--name", "test_ghost_exp"])
@@ -968,7 +962,7 @@ def test_no_experiments_w_name(clean_db, monkeypatch, capsys):
     assert captured == "No experiment found\n"
 
 
-def test_experiment_wout_child_w_name(clean_db, unrelated_with_trials, capsys):
+def test_experiment_wout_child_w_name(unrelated_with_trials, capsys):
     """Test status with the name argument and no child."""
     orion.core.cli.main(["status", "--name", "test_single_exp"])
 
@@ -992,7 +986,7 @@ suspended             1
     assert captured == expected
 
 
-def test_experiment_w_child_w_name(clean_db, three_experiments_with_trials, capsys):
+def test_experiment_w_child_w_name(three_experiments_with_trials, capsys):
     """Test status with the name argument and one child."""
     orion.core.cli.main(["status", "--name", "test_double_exp"])
 
@@ -1028,7 +1022,7 @@ suspended             1
     assert captured == expected
 
 
-def test_experiment_w_parent_w_name(clean_db, three_experiments_with_trials, capsys):
+def test_experiment_w_parent_w_name(three_experiments_with_trials, capsys):
     """Test status with the name argument and one parent."""
     orion.core.cli.main(["status", "--name", "test_double_exp_child"])
 
@@ -1052,7 +1046,7 @@ suspended             1
     assert captured == expected
 
 
-def test_experiment_same_name_wout_exv(clean_db, three_experiments_same_name, capsys):
+def test_experiment_same_name_wout_exv(three_experiments_same_name, capsys):
     """Test status with three experiments having the same name but different versions."""
     orion.core.cli.main(["status"])
 
@@ -1069,9 +1063,7 @@ empty
     assert captured == expected
 
 
-def test_experiment_same_name_wout_exv_w_name(
-    clean_db, three_experiments_same_name, capsys
-):
+def test_experiment_same_name_wout_exv_w_name(three_experiments_same_name, capsys):
     """Test status with three experiments having the same name but different versions."""
     orion.core.cli.main(["status", "--name", "test_single_exp"])
 
@@ -1089,7 +1081,7 @@ empty
 
 
 def test_experiment_same_name_wout_exv_w_child_w_name(
-    clean_db, three_experiments_family_same_name, capsys
+    three_experiments_family_same_name, capsys
 ):
     """Test status name with two experiments having the same name and one with a child."""
     orion.core.cli.main(["status", "--name", "test_single_exp"])
@@ -1118,7 +1110,7 @@ empty
 
 
 def test_experiment_same_name_wout_exv_w_c_w_child_w_name(
-    clean_db, three_experiments_family_same_name, capsys
+    three_experiments_family_same_name, capsys
 ):
     """Test status name collapsed with two experiments having the same name and one with a child."""
     orion.core.cli.main(["status", "--name", "test_single_exp", "--collapse"])
@@ -1137,7 +1129,7 @@ empty
 
 
 def test_experiment_same_name_wout_exv_w_child(
-    clean_db, three_experiments_family_same_name, capsys
+    three_experiments_family_same_name, capsys
 ):
     """Test status with two experiments having the same name and one with a child."""
     orion.core.cli.main(["status"])
@@ -1165,7 +1157,7 @@ empty
     assert captured == expected
 
 
-def test_experiment_same_name_w_exv(clean_db, three_experiments_same_name, capsys):
+def test_experiment_same_name_w_exv(three_experiments_same_name, capsys):
     """Test status with three experiments with the same name and `--expand-verions`."""
     orion.core.cli.main(["status", "--expand-versions"])
 
@@ -1192,9 +1184,7 @@ empty
     assert captured == expected
 
 
-def test_experiment_same_name_w_exv_w_child(
-    clean_db, three_experiments_family_same_name, capsys
-):
+def test_experiment_same_name_w_exv_w_child(three_experiments_family_same_name, capsys):
     """Test status with two experiments having the same name and one with a child."""
     orion.core.cli.main(["status", "--expand-versions"])
 
@@ -1221,7 +1211,7 @@ empty
     assert captured == expected
 
 
-def test_experiment_specific_version(clean_db, three_experiments_same_name, capsys):
+def test_experiment_specific_version(three_experiments_same_name, capsys):
     """Test status using `--version`."""
     orion.core.cli.main(["status", "--version", "2"])
 
@@ -1238,7 +1228,7 @@ empty
     assert captured == expected
 
 
-def test_experiment_cant_use_version(clean_db, three_experiments_same_name):
+def test_experiment_cant_use_version(three_experiments_same_name):
     """Test status using `--version`."""
     with pytest.raises(RuntimeError) as ex:
         orion.core.cli.main(["status", "--version", "2", "--collapse"])
