@@ -1,6 +1,6 @@
 """Common fixtures and utils for configuration tests."""
-from orion.algo.base import (BaseAlgorithm, OptimizationAlgorithm)
-from orion.core.worker.strategy import (BaseParallelStrategy, Strategy)
+from orion.algo.base import BaseAlgorithm, OptimizationAlgorithm
+from orion.core.worker.strategy import BaseParallelStrategy, Strategy
 
 
 def __init__(self, *args, **params):
@@ -19,22 +19,18 @@ def configuration(self):
     return {self.__class__.__name__.lower(): self.params}
 
 
-for char in 'ABCDE':
-    algo_class = type(
-        f'A{char}',
-        (BaseAlgorithm, ),
-        {'suggest': stub, 'observe': stub})
+for char in "ABCDE":
+    algo_class = type(f"A{char}", (BaseAlgorithm,), {"suggest": stub, "observe": stub})
 
     # Hack it into being discoverable
     OptimizationAlgorithm.types.append(algo_class)
     OptimizationAlgorithm.typenames.append(algo_class.__name__.lower())
 
 
-for char in 'ABCDE':
+for char in "ABCDE":
     strategy_class = type(
-        f'S{char}',
-        (BaseParallelStrategy, ),
-        {'observe': stub, '__init__': __init__})
+        f"S{char}", (BaseParallelStrategy,), {"observe": stub, "__init__": __init__}
+    )
 
     strategy_class.configuration = property(configuration)
 
