@@ -7,8 +7,15 @@ import pytest
 from scipy.stats import norm
 
 from orion.algo.space import Categorical, Fidelity, Integer, Real, Space
-from orion.algo.tpe import adaptive_parzen_estimator, CategoricalSampler, \
-    compute_max_ei_point, GMMSampler, ramp_up_weights, TPE
+from orion.algo.tpe import (
+    TPE,
+    CategoricalSampler,
+    GMMSampler,
+    adaptive_parzen_estimator,
+    compute_max_ei_point,
+    ramp_up_weights,
+)
+from orion.core.worker.transformer import build_required_space
 
 
 @pytest.fixture()
@@ -16,14 +23,14 @@ def space():
     """Return an optimization space"""
     space = Space()
 
-    dim1 = Real('yolo1', 'uniform', -10, 20)
+    dim1 = Real("yolo1", "uniform", -10, 20)
     space.register(dim1)
 
-    dim2 = Integer('yolo2', 'uniform', -5, 10)
+    dim2 = Integer("yolo2", "uniform", -5, 10)
     space.register(dim2)
 
-    categories = ['a', 0.1, 2, 'c']
-    dim3 = Categorical('yolo3', categories)
+    categories = ["a", 0.1, 2, "c"]
+    dim3 = Categorical("yolo3", categories)
     space.register(dim3)
 
     return space
@@ -75,30 +82,33 @@ def test_adaptive_parzen_normal_estimator():
     high = 5
 
     obs_mus = [1.2]
-    mus, sigmas, weights = adaptive_parzen_estimator(obs_mus, low, high, prior_weight=1.0,
-                                                     equal_weight=False, flat_num=25)
+    mus, sigmas, weights = adaptive_parzen_estimator(
+        obs_mus, low, high, prior_weight=1.0, equal_weight=False, flat_num=25
+    )
     assert list(mus) == [1.2, 2]
     assert list(sigmas) == [3, 6]
     assert list(weights) == [1.0 / 2, 1.0 / 2]
 
     obs_mus = [3.4]
-    mus, sigmas, weights = adaptive_parzen_estimator(obs_mus, low, high, prior_weight=0.5,
-                                                     equal_weight=False, flat_num=25)
+    mus, sigmas, weights = adaptive_parzen_estimator(
+        obs_mus, low, high, prior_weight=0.5, equal_weight=False, flat_num=25
+    )
     assert list(mus) == [2, 3.4]
     assert list(sigmas) == [6, 3]
     assert list(weights) == [0.5 / 1.5, 1.0 / 1.5]
 
     obs_mus = numpy.linspace(-1, 5, num=30, endpoint=False)
-    mus, sigmas, weights = adaptive_parzen_estimator(obs_mus, low, high, prior_weight=1.0,
-                                                     equal_weight=False, flat_num=25)
+    mus, sigmas, weights = adaptive_parzen_estimator(
+        obs_mus, low, high, prior_weight=1.0, equal_weight=False, flat_num=25
+    )
 
     ramp = numpy.linspace(1.0 / 30, 1.0, num=30 - 25)
     full = numpy.ones(25 + 1)
-    all_weights = (numpy.concatenate([ramp, full]))
+    all_weights = numpy.concatenate([ramp, full])
 
     assert len(mus) == len(sigmas) == len(weights) == 30 + 1
-    assert numpy.all(weights[:30 - 25] == ramp / all_weights.sum())
-    assert numpy.all(weights[30 - 25:] == 1 / all_weights.sum())
+    assert numpy.all(weights[: 30 - 25] == ramp / all_weights.sum())
+    assert numpy.all(weights[30 - 25 :] == 1 / all_weights.sum())
     assert numpy.all(sigmas == 6 / 10)
 
 
@@ -109,41 +119,48 @@ def test_adaptive_parzen_normal_estimator_weight():
     high = 5
 
     # equal weight
-    mus, sigmas, weights = adaptive_parzen_estimator(obs_mus, low, high, prior_weight=1.0,
-                                                     equal_weight=True, flat_num=25)
+    mus, sigmas, weights = adaptive_parzen_estimator(
+        obs_mus, low, high, prior_weight=1.0, equal_weight=True, flat_num=25
+    )
     assert numpy.all(weights == 1 / 31)
     assert numpy.all(sigmas == 6 / 10)
 
     # prior weight
-    mus, sigmas, weights = adaptive_parzen_estimator(obs_mus, low, high, prior_weight=0.5,
-                                                     equal_weight=False, flat_num=25)
+    mus, sigmas, weights = adaptive_parzen_estimator(
+        obs_mus, low, high, prior_weight=0.5, equal_weight=False, flat_num=25
+    )
 
     ramp = numpy.linspace(1.0 / 30, 1.0, num=30 - 25)
     full = numpy.ones(25 + 1)
-    all_weights = (numpy.concatenate([ramp, full]))
+    all_weights = numpy.concatenate([ramp, full])
     prior_pos = numpy.searchsorted(mus, 2)
     all_weights[prior_pos] = 0.5
 
-    assert numpy.all(weights[:30 - 25] == (numpy.linspace(1.0 / 30, 1.0, num=30 - 25) /
-                                           all_weights.sum()))
-    assert numpy.all(weights[33 - 25:prior_pos] == 1 / all_weights.sum())
+    assert numpy.all(
+        weights[: 30 - 25]
+        == (numpy.linspace(1.0 / 30, 1.0, num=30 - 25) / all_weights.sum())
+    )
+    assert numpy.all(weights[33 - 25 : prior_pos] == 1 / all_weights.sum())
     assert weights[prior_pos] == 0.5 / all_weights.sum()
-    assert numpy.all(weights[prior_pos + 1:] == 1 / all_weights.sum())
+    assert numpy.all(weights[prior_pos + 1 :] == 1 / all_weights.sum())
     assert numpy.all(sigmas == 6 / 10)
 
     # full weights number
-    mus, sigmas, weights = adaptive_parzen_estimator(obs_mus, low, high, prior_weight=1.0,
-                                                     equal_weight=False, flat_num=15)
+    mus, sigmas, weights = adaptive_parzen_estimator(
+        obs_mus, low, high, prior_weight=1.0, equal_weight=False, flat_num=15
+    )
 
     ramp = numpy.linspace(1.0 / 30, 1.0, num=30 - 15)
     full = numpy.ones(15 + 1)
-    all_weights = (numpy.concatenate([ramp, full]))
+    all_weights = numpy.concatenate([ramp, full])
     prior_pos = numpy.searchsorted(mus, 2)
     all_weights[prior_pos] = 1.0
 
-    assert numpy.all(weights[:30 - 15] == (numpy.linspace(1.0 / 30, 1.0, num=30 - 15) /
-                                           all_weights.sum()))
-    assert numpy.all(weights[30 - 15:] == 1 / all_weights.sum())
+    assert numpy.all(
+        weights[: 30 - 15]
+        == (numpy.linspace(1.0 / 30, 1.0, num=30 - 15) / all_weights.sum())
+    )
+    assert numpy.all(weights[30 - 15 :] == 1 / all_weights.sum())
     assert numpy.all(sigmas == 6 / 10)
 
 
@@ -153,38 +170,42 @@ def test_adaptive_parzen_normal_estimator_sigma_clip():
     high = 5
 
     obs_mus = numpy.linspace(-1, 5, num=8, endpoint=False)
-    mus, sigmas, weights = adaptive_parzen_estimator(obs_mus, low, high, prior_weight=1.0,
-                                                     equal_weight=False, flat_num=25)
+    mus, sigmas, weights = adaptive_parzen_estimator(
+        obs_mus, low, high, prior_weight=1.0, equal_weight=False, flat_num=25
+    )
     assert len(mus) == len(sigmas) == len(weights) == 8 + 1
     assert numpy.all(weights == 1 / 9)
     assert numpy.all(sigmas == 6 / 8)
 
     obs_mus = numpy.random.uniform(-1, 5, 30)
-    mus, sigmas, weights = adaptive_parzen_estimator(obs_mus, low, high, prior_weight=1.0,
-                                                     equal_weight=False, flat_num=25)
+    mus, sigmas, weights = adaptive_parzen_estimator(
+        obs_mus, low, high, prior_weight=1.0, equal_weight=False, flat_num=25
+    )
 
     assert len(mus) == len(sigmas) == len(weights) == 30 + 1
     assert numpy.all(weights[-25:] == weights[-1])
     assert numpy.all(sigmas <= 6) and numpy.all(sigmas >= 6 / 10)
 
     obs_mus = numpy.random.uniform(-1, 5, 400)
-    mus, sigmas, weights = adaptive_parzen_estimator(obs_mus, low, high, prior_weight=1.0,
-                                                     equal_weight=False, flat_num=25)
+    mus, sigmas, weights = adaptive_parzen_estimator(
+        obs_mus, low, high, prior_weight=1.0, equal_weight=False, flat_num=25
+    )
 
     assert len(mus) == len(sigmas) == len(weights) == 400 + 1
     assert numpy.all(weights[-25:] == weights[-1])
     assert numpy.all(sigmas <= 6) and numpy.all(sigmas >= 6 / 20)
 
     obs_mus = numpy.random.uniform(-1, 5, 10000)
-    mus, sigmas, weights = adaptive_parzen_estimator(obs_mus, low, high, prior_weight=1.0,
-                                                     equal_weight=False, flat_num=25)
+    mus, sigmas, weights = adaptive_parzen_estimator(
+        obs_mus, low, high, prior_weight=1.0, equal_weight=False, flat_num=25
+    )
 
     assert len(mus) == len(sigmas) == len(weights) == 10000 + 1
     assert numpy.all(weights[-25:] == weights[-1])
     assert numpy.all(sigmas <= 6) and numpy.all(sigmas >= 6 / 100)
 
 
-class TestCategoricalSampler():
+class TestCategoricalSampler:
     """Tests for TPE Categorical Sampler"""
 
     def test_cat_sampler_creation(self, tpe):
@@ -195,7 +216,7 @@ class TestCategoricalSampler():
         assert len(cat_sampler.weights) == len(choices)
 
         obs = [0, 3, 9]
-        choices = ['a', 'b', 11, 15, 17, 18, 19, 20, 25, 'c']
+        choices = ["a", "b", 11, 15, 17, 18, 19, 20, 25, "c"]
         cat_sampler = CategoricalSampler(tpe, obs, choices)
 
         assert len(cat_sampler.weights) == len(choices)
@@ -218,7 +239,7 @@ class TestCategoricalSampler():
 
         ramp = numpy.linspace(1.0 / 100, 1.0, num=100 - 30)
         full = numpy.ones(30)
-        ramp_weights = (numpy.concatenate([ramp, full]))
+        ramp_weights = numpy.concatenate([ramp, full])
 
         counts_obs = numpy.bincount(obs, weights=ramp_weights) + 0.5
         weights = counts_obs / counts_obs.sum()
@@ -228,7 +249,7 @@ class TestCategoricalSampler():
     def test_sample(self, tpe):
         """Test CategoricalSampler sample function"""
         obs = numpy.random.randint(0, 10, 100)
-        choices = ['a', 'b', 11, 15, 17, 18, 19, 20, 25, 'c']
+        choices = ["a", "b", 11, 15, 17, 18, 19, 20, 25, "c"]
         cat_sampler = CategoricalSampler(tpe, obs, choices)
 
         points = cat_sampler.sample(25)
@@ -255,17 +276,19 @@ class TestCategoricalSampler():
     def test_get_loglikelis(self, tpe):
         """Test to get log likelis of points"""
         obs = numpy.random.randint(0, 10, 100)
-        choices = ['a', 'b', 11, 15, 17, 18, 19, 20, 25, 'c']
+        choices = ["a", "b", 11, 15, 17, 18, 19, 20, 25, "c"]
         cat_sampler = CategoricalSampler(tpe, obs, choices)
 
         points = cat_sampler.sample(25)
 
         likelis = cat_sampler.get_loglikelis(points)
 
-        assert numpy.all(likelis == numpy.log(numpy.asarray(cat_sampler.weights)[points]))
+        assert numpy.all(
+            likelis == numpy.log(numpy.asarray(cat_sampler.weights)[points])
+        )
 
 
-class TestGMMSampler():
+class TestGMMSampler:
     """Tests for TPE GMM Sampler"""
 
     def test_gmm_sampler_creation(self, tpe):
@@ -345,7 +368,7 @@ class TestGMMSampler():
         assert len(likelis) == len(points)
 
 
-class TestTPE():
+class TestTPE:
     """Tests for the algo TPE."""
 
     def test_seed_rng(self, tpe):
@@ -370,40 +393,36 @@ class TestTPE():
     def test_unsupported_space(self):
         """Test tpe only work for supported search space"""
         space = Space()
-        dim1 = Real('yolo1', 'uniform', -10, 10)
+        dim1 = Real("yolo1", "uniform", -10, 10)
         space.register(dim1)
-        dim2 = Real('yolo2', 'reciprocal', 10, 20)
+        dim2 = Real("yolo2", "reciprocal", 10, 20)
         space.register(dim2)
-        categories = ['a', 0.1, 2, 'c']
-        dim3 = Categorical('yolo3', categories)
+        categories = ["a", 0.1, 2, "c"]
+        dim3 = Categorical("yolo3", categories)
         space.register(dim3)
-        dim4 = Fidelity('epoch', 1, 9, 3)
+        dim4 = Fidelity("epoch", 1, 9, 3)
         space.register(dim4)
         TPE(space)
 
         space = Space()
-        dim = Real('yolo1', 'norm', 0.9)
+        dim = Real("yolo1", "norm", 0.9)
         space.register(dim)
 
         with pytest.raises(ValueError) as ex:
-            TPE(space)
+            tpe = TPE(space)
+            tpe.space = build_required_space(
+                space, shape_requirement=TPE.requires_shape
+            )
 
-        assert 'TPE now only supports uniform, loguniform, uniform discrete and choices' \
-               in str(ex.value)
-
-        space = Space()
-        dim = Real('yolo1', 'uniform', 0.9, shape=(2, 1))
-        space.register(dim)
-
-        with pytest.raises(ValueError) as ex:
-            TPE(space)
-
-        assert 'TPE now only supports 1D shape' in str(ex.value)
+        assert (
+            "TPE now only supports uniform, loguniform, uniform discrete and choices"
+            in str(ex.value)
+        )
 
     def test_split_trials(self, tpe):
         """Test observed trials can be split based on TPE gamma"""
         space = Space()
-        dim1 = Real('yolo1', 'uniform', -3, 6)
+        dim1 = Real("yolo1", "uniform", -3, 6)
         space.register(dim1)
 
         tpe.space = space
@@ -414,7 +433,7 @@ class TestTPE():
         numpy.random.shuffle(points_results)
         points, results = zip(*points_results)
         for point, result in zip(points, results):
-            tpe.observe([[point]], [{'objective': result}])
+            tpe.observe([[point]], [{"objective": result}])
 
         tpe.gamma = 0.25
         below_points, above_points = tpe.split_trials()
@@ -431,10 +450,10 @@ class TestTPE():
     def test_sample_int_dimension(self):
         """Test sample values for a integer dimension"""
         space = Space()
-        dim1 = Integer('yolo1', 'uniform', -10, 20)
+        dim1 = Integer("yolo1", "uniform", -10, 20)
         space.register(dim1)
 
-        dim2 = Integer('yolo2', 'uniform', -5, 10, shape=(2))
+        dim2 = Integer("yolo2", "uniform", -5, 10, shape=(2))
         space.register(dim2)
 
         tpe = TPE(space)
@@ -442,8 +461,9 @@ class TestTPE():
         obs_points = numpy.random.randint(-10, 10, 100)
         below_points = [obs_points[:25]]
         above_points = [obs_points[25:]]
-        points = tpe.sample_one_dimension(dim1, 1,
-                                          below_points, above_points, tpe._sample_int_point)
+        points = tpe.sample_one_dimension(
+            dim1, 1, below_points, above_points, tpe._sample_int_point
+        )
         points = numpy.asarray(points)
         assert len(points) == 1
         assert all(points >= -10)
@@ -451,8 +471,9 @@ class TestTPE():
 
         obs_points_below = numpy.random.randint(-10, 0, 25).reshape(1, 25)
         obs_points_above = numpy.random.randint(0, 10, 75).reshape(1, 75)
-        points = tpe.sample_one_dimension(dim1, 1,
-                                          obs_points_below, obs_points_above, tpe._sample_int_point)
+        points = tpe.sample_one_dimension(
+            dim1, 1, obs_points_below, obs_points_above, tpe._sample_int_point
+        )
         points = numpy.asarray(points)
         assert len(points) == 1
         assert all(points >= -10)
@@ -461,25 +482,27 @@ class TestTPE():
         obs_points = numpy.random.randint(-5, 5, 100)
         below_points = [obs_points[:25], obs_points[25:50]]
         above_points = [obs_points[50:75], obs_points[75:]]
-        points = tpe.sample_one_dimension(dim2, 2,
-                                          below_points, above_points, tpe._sample_int_point)
+        points = tpe.sample_one_dimension(
+            dim2, 2, below_points, above_points, tpe._sample_int_point
+        )
         points = numpy.asarray(points)
         assert len(points) == 2
         assert all(points >= -10)
         assert all(points < 10)
 
         tpe.n_ei_candidates = 0
-        points = tpe.sample_one_dimension(dim2, 2,
-                                          below_points, above_points, tpe._sample_int_point)
+        points = tpe.sample_one_dimension(
+            dim2, 2, below_points, above_points, tpe._sample_int_point
+        )
         assert len(points) == 0
 
     def test_sample_categorical_dimension(self):
         """Test sample values for a categorical dimension"""
         space = Space()
-        categories = ['a', 'b', 11, 15, 17, 18, 19, 20, 25, 'c']
-        dim1 = Categorical('yolo1', categories)
+        categories = ["a", "b", 11, 15, 17, 18, 19, 20, 25, "c"]
+        dim1 = Categorical("yolo1", categories)
         space.register(dim1)
-        dim2 = Categorical('yolo2', categories, shape=(2))
+        dim2 = Categorical("yolo2", categories, shape=(2))
         space.register(dim2)
 
         tpe = TPE(space)
@@ -488,8 +511,9 @@ class TestTPE():
         obs_points = [categories[point] for point in obs_points]
         below_points = [obs_points[:25]]
         above_points = [obs_points[25:]]
-        points = tpe.sample_one_dimension(dim1, 1,
-                                          below_points, above_points, tpe._sample_categorical_point)
+        points = tpe.sample_one_dimension(
+            dim1, 1, below_points, above_points, tpe._sample_categorical_point
+        )
         assert len(points) == 1
         assert points[0] in categories
 
@@ -497,8 +521,9 @@ class TestTPE():
         obs_points_above = numpy.random.randint(3, 10, 75)
         below_points = [[categories[point] for point in obs_points_below]]
         above_points = [[categories[point] for point in obs_points_above]]
-        points = tpe.sample_one_dimension(dim1, 1,
-                                          below_points, above_points, tpe._sample_categorical_point)
+        points = tpe.sample_one_dimension(
+            dim1, 1, below_points, above_points, tpe._sample_categorical_point
+        )
         assert len(points) == 1
         assert points[0] in categories[:3]
 
@@ -507,33 +532,34 @@ class TestTPE():
         below_points = [obs_points[:25], obs_points[25:50]]
         above_points = [obs_points[50:75], obs_points[75:]]
 
-        points = tpe.sample_one_dimension(dim2, 2,
-                                          below_points, above_points, tpe._sample_categorical_point)
+        points = tpe.sample_one_dimension(
+            dim2, 2, below_points, above_points, tpe._sample_categorical_point
+        )
         assert len(points) == 2
         assert points[0] in categories
         assert points[1] in categories
 
         tpe.n_ei_candidates = 0
-        points = tpe.sample_one_dimension(dim2, 2,
-                                          below_points, above_points, tpe._sample_categorical_point)
+        points = tpe.sample_one_dimension(
+            dim2, 2, below_points, above_points, tpe._sample_categorical_point
+        )
         assert len(points) == 0
 
     def test_sample_real_dimension(self):
         """Test sample values for a real dimension"""
         space = Space()
-        dim1 = Real('yolo1', 'uniform', -10, 20)
+        dim1 = Real("yolo1", "uniform", -10, 20)
         space.register(dim1)
-        dim2 = Real('yolo2', 'uniform', -5, 10, shape=(2))
+        dim2 = Real("yolo2", "uniform", -5, 10, shape=(2))
         space.register(dim2)
-        dim3 = Real('yolo3', 'reciprocal', 1, 20)
+        dim3 = Real("yolo3", "reciprocal", 1, 20)
         space.register(dim3)
 
         tpe = TPE(space)
         points = numpy.random.uniform(-10, 10, 20)
         below_points = [points[:8]]
         above_points = [points[8:]]
-        points = tpe._sample_real_dimension(dim1, 1,
-                                            below_points, above_points)
+        points = tpe._sample_real_dimension(dim1, 1, below_points, above_points)
         points = numpy.asarray(points)
         assert len(points) == 1
         assert all(points >= -10)
@@ -542,8 +568,7 @@ class TestTPE():
         points = numpy.random.uniform(1, 20, 20)
         below_points = [points[:8]]
         above_points = [points[8:]]
-        points = tpe._sample_real_dimension(dim3, 1,
-                                            below_points, above_points)
+        points = tpe._sample_real_dimension(dim3, 1, below_points, above_points)
         points = numpy.asarray(points)
         assert len(points) == 1
         assert all(points >= 1)
@@ -551,8 +576,7 @@ class TestTPE():
 
         below_points = numpy.random.uniform(-10, 0, 25).reshape(1, 25)
         above_points = numpy.random.uniform(0, 10, 75).reshape(1, 75)
-        points = tpe._sample_real_dimension(dim1, 1,
-                                            below_points, above_points)
+        points = tpe._sample_real_dimension(dim1, 1, below_points, above_points)
         points = numpy.asarray(points)
         assert len(points) == 1
         assert all(points >= -10)
@@ -561,16 +585,14 @@ class TestTPE():
         points = numpy.random.uniform(-5, 5, 32)
         below_points = [points[:8], points[8:16]]
         above_points = [points[16:24], points[24:]]
-        points = tpe._sample_real_dimension(dim2, 2,
-                                            below_points, above_points)
+        points = tpe._sample_real_dimension(dim2, 2, below_points, above_points)
         points = numpy.asarray(points)
         assert len(points) == 2
         assert all(points >= -10)
         assert all(points < 10)
 
         tpe.n_ei_candidates = 0
-        points = tpe._sample_real_dimension(dim2, 2,
-                                            below_points, above_points)
+        points = tpe._sample_real_dimension(dim2, 2, below_points, above_points)
         assert len(points) == 0
 
     def test_suggest(self, tpe):
@@ -582,7 +604,7 @@ class TestTPE():
             assert len(point) == 1
             assert len(point[0]) == 3
             assert not isinstance(point[0][0], tuple)
-            tpe.observe(point, [{'objective': results[i]}])
+            tpe.observe(point, [{"objective": results[i]}])
 
         point = tpe.suggest(1)
         assert len(point) == 1
@@ -592,9 +614,9 @@ class TestTPE():
     def test_1d_shape(self, tpe):
         """Test suggest with 1D shape dimensions"""
         space = Space()
-        dim1 = Real('yolo1', 'uniform', -3, 6, shape=(2))
+        dim1 = Real("yolo1", "uniform", -3, 6, shape=(2))
         space.register(dim1)
-        dim2 = Real('yolo2', 'uniform', -2, 4)
+        dim2 = Real("yolo2", "uniform", -2, 4)
         space.register(dim2)
 
         tpe.space = space
@@ -606,7 +628,7 @@ class TestTPE():
             assert len(point) == 1
             assert len(point[0]) == 2
             assert len(point[0][0]) == 2
-            tpe.observe(point, [{'objective': results[i]}])
+            tpe.observe(point, [{"objective": results[i]}])
 
         point = tpe.suggest(1)
         assert len(point) == 1
@@ -615,28 +637,28 @@ class TestTPE():
 
     def test_suggest_initial_points(self, tpe, monkeypatch):
         """Test that initial points can be sampled correctly"""
-        points = [(i, i - 6, 'c') for i in range(1, 12)]
+        points = [(i, i - 6, "c") for i in range(1, 12)]
 
         global index
         index = 0
 
         def sample(num=1, seed=None):
             global index
-            pts = points[index:index + num]
+            pts = points[index : index + num]
             index += num
             return pts
 
-        monkeypatch.setattr(tpe.space, 'sample', sample)
+        monkeypatch.setattr(tpe.space, "sample", sample)
 
         tpe.n_initial_points = 10
         results = numpy.random.random(10)
         for i in range(1, 11):
             point = tpe.suggest(1)[0]
-            assert point == (i, i - 6, 'c')
-            tpe.observe([point], [{'objective': results[i - 1]}])
+            assert point == (i, i - 6, "c")
+            tpe.observe([point], [{"objective": results[i - 1]}])
 
         point = tpe.suggest(1)[0]
-        assert point != (11, 5, 'c')
+        assert point != (11, 5, "c")
 
     def test_suggest_ei_candidates(self, tpe):
         """Test suggest with no shape dimensions"""
@@ -649,7 +671,7 @@ class TestTPE():
             assert len(point) == 1
             assert len(point[0]) == 3
             assert not isinstance(point[0][0], tuple)
-            tpe.observe(point, [{'objective': results[i]}])
+            tpe.observe(point, [{"objective": results[i]}])
 
         point = tpe.suggest(1)
         assert not point
