@@ -378,7 +378,7 @@ class TestRelease:
         with create_experiment(config, base_trial) as (cfg, experiment, client):
             trial = Trial(experiment="idontexist", params=cfg.trials[1]["params"])
 
-            def do_nada(trial):
+            def do_nada(trial, **kwargs):
                 """Don't do anything"""
                 return None
 
@@ -420,12 +420,32 @@ class TestRelease:
             with pytest.raises(RuntimeError) as exc:
                 client.release(trial)
 
-            assert "Trial {} had no pacemakers. Was is reserved properly?".format(
-                trial.id
-            ) == str(exc.value)
+            assert "Trial {} was already released locally.".format(trial.id) == str(
+                exc.value
+            )
 
             assert client._pacemakers == {}
 
+    def test_release_already_released_but_incorrectly(self):
+        """Verify that incorrectly released trials have its pacemaker stopped properly"""
+        with create_experiment(config, base_trial) as (cfg, experiment, client):
+            trial = client.get_trial(uid=cfg.trials[1]["_id"])
+            client.reserve(trial)
+            pacemaker = client._pacemakers[trial.id]
+            assert trial.status == "reserved"
+            experiment.set_trial_status(trial, "interrupted")
+            assert trial.status == "interrupted"
+
+            with pytest.raises(RuntimeError) as exc:
+                client.release(trial)
+
+            assert "Trial {} was already released locally.".format(trial.id) == str(
+                exc.value
+            )
+
+            assert client._pacemakers == {}
+            assert not pacemaker.is_alive()
+
 
 @pytest.mark.usefixtures("version_XYZ")
 class TestClose:
@@ -439,14 +459,11 @@ class TestClose:
     def test_close_with_reserved(self):
         """Test client cannot be closed if trials are reserved."""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = client.suggest()
+            with client.suggest() as trial:
+                with pytest.raises(RuntimeError) as exc:
+                    client.close()
 
-            with pytest.raises(RuntimeError) as exc:
-                client.close()
-
-            assert "There is still reserved trials" in str(exc.value)
-
-            client.release(trial)
+                assert "There is still reserved trials" in str(exc.value)
 
     def test_close_unregister_atexit(self, monkeypatch):
         """Test close properly unregister the atexit function"""
@@ -476,10 +493,10 @@ class TestBroken:
     def test_broken_trial(self):
         """Test that broken trials are detected"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = client.suggest()
-            assert trial.status == "reserved"
-
-            atexit._run_exitfuncs()
+            with pytest.raises(RuntimeError):
+                with client.suggest() as trial:
+                    assert trial.status == "reserved"
+                    raise RuntimeError("Dummy failure!")
 
             assert client._pacemakers == {}
             assert client.get_trial(trial).status == "broken"
@@ -499,13 +516,11 @@ class TestBroken:
                 _,
                 client2,
             ):
-                trial1 = client1.suggest()
-                trial2 = client2.suggest()
-
-                assert trial1.status == "reserved"
-                assert trial2.status == "reserved"
-
-                atexit._run_exitfuncs()
+                with pytest.raises(RuntimeError):
+                    with client1.suggest() as trial1, client2.suggest() as trial2:
+                        assert trial1.status == "reserved"
+                        assert trial2.status == "reserved"
+                        raise RuntimeError("Dummy failure!")
 
                 assert client1._pacemakers == {}
                 assert client2._pacemakers == {}
@@ -559,17 +574,32 @@ class TestBroken:
     def test_interrupted_trial(self):
         """Test that interrupted trials are not set to broken"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = client.suggest()
-            assert trial.status == "reserved"
-
-            try:
-                raise KeyboardInterrupt
-            except KeyboardInterrupt as e:
-                atexit._run_exitfuncs()
+            with pytest.raises(KeyboardInterrupt):
+                with client.suggest() as trial:
+                    assert trial.status == "reserved"
+                    raise KeyboardInterrupt
 
             assert client._pacemakers == {}
             assert client.get_trial(trial).status == "interrupted"
 
+    def test_completed_then_interrupted_trial(self):
+        """Test that interrupted trials are not set to broken"""
+        with create_experiment(config, base_trial) as (cfg, experiment, client):
+            with pytest.raises(KeyboardInterrupt):
+                with client.suggest() as trial:
+                    assert trial.status == "reserved"
+                    assert trial.results == []
+                    assert get_storage().get_trial(trial).objective is None
+                    client.observe(
+                        trial, [dict(name="objective", type="objective", value=101)]
+                    )
+                    assert get_storage().get_trial(trial).objective.value == 101
+                    assert trial.status == "completed"
+                    raise KeyboardInterrupt
+
+            assert client._pacemakers == {}
+            assert client.get_trial(trial).status == "completed"
+
 
 @pytest.mark.usefixtures("version_XYZ")
 class TestSuggest:
@@ -796,7 +826,7 @@ class TestObserve:
                     trial, [dict(name="objective", type="objective", value=101)]
                 )
 
-            assert "Trial {} had no pacemakers. Was is reserved properly?".format(
+            assert "Trial {} had no pacemakers. Was it reserved properly?".format(
                 trial.id
             ) == str(exc.value)
 
@@ -846,6 +876,20 @@ class TestObserve:
             )
             assert client._pacemakers == {}
 
+    def test_observe_under_with(self):
+        with create_experiment(config, base_trial) as (cfg, experiment, client):
+            with client.suggest() as trial:
+                assert trial.status == "reserved"
+                assert trial.results == []
+                assert get_storage().get_trial(trial).objective is None
+                client.observe(
+                    trial, [dict(name="objective", type="objective", value=101)]
+                )
+                assert get_storage().get_trial(trial).objective.value == 101
+                assert trial.status == "completed"
+
+            assert trial.status == "completed"  # Still completed after __exit__
+
 
 @pytest.mark.usefixtures("version_XYZ")
 class TestWorkon:
