@@ -15,9 +15,9 @@ from orion.core.io.config import Configuration, ConfigurationError
 @pytest.fixture
 def yaml_path():
     """Create a temporary yaml file and return the path"""
-    file_path = './my.yaml'
-    with open(file_path, 'w') as f:
-        f.write(yaml.dump({'test': 'from my yaml!'}))
+    file_path = "./my.yaml"
+    with open(file_path, "w") as f:
+        f.write(yaml.dump({"test": "from my yaml!"}))
 
     yield file_path
 
@@ -27,9 +27,9 @@ def yaml_path():
 @pytest.fixture
 def broken_yaml_path():
     """Create a temporary yaml file and return the path"""
-    file_path = './my.yaml'
-    with open(file_path, 'w') as f:
-        f.write(yaml.dump({'coucou': 'from my yaml!'}))
+    file_path = "./my.yaml"
+    with open(file_path, "w") as f:
+        f.write(yaml.dump({"coucou": "from my yaml!"}))
 
     yield file_path
 
@@ -39,10 +39,16 @@ def broken_yaml_path():
 @pytest.fixture
 def subdict_yaml_path():
     """Create a temporary yaml file with subdicts and return the path"""
-    file_path = './my.yaml'
-    with open(file_path, 'w') as f:
-        f.write(yaml.dump({'test': {'i am': 'a sub-dict'},
-                           'test2': {'test': {'me is': 'sub-conf sub-dict'}}}))
+    file_path = "./my.yaml"
+    with open(file_path, "w") as f:
+        f.write(
+            yaml.dump(
+                {
+                    "test": {"i am": "a sub-dict"},
+                    "test2": {"test": {"me is": "sub-conf sub-dict"}},
+                }
+            )
+        )
 
     yield file_path
 
@@ -55,7 +61,7 @@ def test_fetch_non_existing_option():
     with pytest.raises(ConfigurationError) as exc:
         config.voici_voila
 
-    assert 'Configuration does not have an attribute \'voici_voila\'.' in str(exc.value)
+    assert "Configuration does not have an attribute 'voici_voila'." in str(exc.value)
 
 
 def test_access_to_config():
@@ -81,11 +87,11 @@ def test_set_subconfig():
 def test_access_config_without_values():
     """Test that access to config without values raises ConfigurationError"""
     config = Configuration()
-    config.add_option('test', option_type=int)
+    config.add_option("test", option_type=int)
     with pytest.raises(ConfigurationError) as exc:
         config.test
 
-    assert 'Configuration not set and no default provided: test.' in str(exc.value)
+    assert "Configuration not set and no default provided: test." in str(exc.value)
 
 
 def test_set_non_existing_option():
@@ -99,7 +105,7 @@ def test_set_non_existing_option():
 def test_set_subconfig_over_option():
     """Test that overwritting an option with a subconfig is not possible"""
     config = Configuration()
-    config.add_option('test', option_type=int)
+    config.add_option("test", option_type=int)
     config.test = 1
     assert config.test == 1
     with pytest.raises(TypeError) as exc:
@@ -110,7 +116,7 @@ def test_set_subconfig_over_option():
 def test_set_int_value():
     """Test that an integer option can have its value set"""
     config = Configuration()
-    config.add_option('test', option_type=int)
+    config.add_option("test", option_type=int)
 
     with pytest.raises(ConfigurationError) as exc:
         config.test
@@ -121,13 +127,15 @@ def test_set_int_value():
     assert config.test == 1
     with pytest.raises(TypeError) as exc:
         config.test = "voici_voila"
-    assert "<class 'int'> cannot be set to voici_voila with type <class 'str'>" in str(exc.value)
+    assert "<class 'int'> cannot be set to voici_voila with type <class 'str'>" in str(
+        exc.value
+    )
 
 
 def test_set_real_value():
     """Test that a float option can have its value set"""
     config = Configuration()
-    config.add_option('test', option_type=float)
+    config.add_option("test", option_type=float)
 
     with pytest.raises(ConfigurationError) as exc:
         config.test
@@ -138,13 +146,16 @@ def test_set_real_value():
     assert config.test == 1.0
     with pytest.raises(TypeError) as exc:
         config.test = "voici_voila"
-    assert "<class 'float'> cannot be set to voici_voila with type <class 'str'>" in str(exc.value)
+    assert (
+        "<class 'float'> cannot be set to voici_voila with type <class 'str'>"
+        in str(exc.value)
+    )
 
 
 def test_set_str_value():
     """Test that a string option can have its value set"""
     config = Configuration()
-    config.add_option('test', option_type=str)
+    config.add_option("test", option_type=str)
 
     with pytest.raises(ConfigurationError):
         config.test
@@ -159,7 +170,7 @@ def test_set_value_of_subconfig_directly():
     """Test that we can access subconfig and set value directly"""
     config = Configuration()
     config.sub = Configuration()
-    config.sub.add_option('test', option_type=str)
+    config.sub.add_option("test", option_type=str)
 
     with pytest.raises(ConfigurationError):
         config.test
@@ -173,14 +184,14 @@ def test_set_value_of_subconfig_directly():
 def test_set_value_like_dict():
     """Test that we can set values like a dictionary"""
     config = Configuration()
-    config.add_option('test', option_type=str)
+    config.add_option("test", option_type=str)
 
     with pytest.raises(ConfigurationError):
         config.test
 
-    config['test'] = "1"
+    config["test"] = "1"
     assert config.test == "1"
-    config['test'] = 1
+    config["test"] = 1
     assert config.test == "1"
 
 
@@ -188,14 +199,14 @@ def test_set_subconfig_value_like_dict():
     """Test that we can set values like a dictionary"""
     config = Configuration()
     config.sub = Configuration()
-    config.sub.add_option('test', option_type=str)
+    config.sub.add_option("test", option_type=str)
 
     with pytest.raises(ConfigurationError):
         config.test
 
-    config['sub.test'] = "1"
+    config["sub.test"] = "1"
     assert config.sub.test == "1"
-    config['sub.test'] = 1
+    config["sub.test"] = 1
     assert config.sub.test == "1"
 
 
@@ -203,8 +214,8 @@ def test_set_invalid_subconfig_value_like_dict():
     """Test that deep keys cannot be set if subconfig does not exist"""
     config = Configuration()
     with pytest.raises(BaseException) as exc:
-        config['sub.test'] = "1"
-    assert 'Configuration does not have an attribute \'sub\'.' in str(exc.value)
+        config["sub.test"] = "1"
+    assert "Configuration does not have an attribute 'sub'." in str(exc.value)
 
 
 def test_yaml_loading_empty_config(yaml_path):
@@ -214,20 +225,22 @@ def test_yaml_loading_empty_config(yaml_path):
     with pytest.raises(ConfigurationError) as exc:
         config.load_yaml(yaml_path)
 
-    assert 'Configuration does not have an attribute \'test\'.' in str(exc.value)
+    assert "Configuration does not have an attribute 'test'." in str(exc.value)
 
 
 def test_default_value():
     """Test that default value is given only when nothing else is available"""
     config = Configuration()
-    config.add_option('test', option_type=str, default="voici_voila")
+    config.add_option("test", option_type=str, default="voici_voila")
     assert config.test == "voici_voila"
 
 
 def test_yaml_precedence(yaml_path):
     """Test that yaml definition has precedence over default values"""
     config = Configuration()
-    config.add_option('test', option_type=str, default="voici_voila", env_var="TOP_SECRET_MESSAGE")
+    config.add_option(
+        "test", option_type=str, default="voici_voila", env_var="TOP_SECRET_MESSAGE"
+    )
     assert config.test == "voici_voila"
 
     config.load_yaml(yaml_path)
@@ -237,15 +250,17 @@ def test_yaml_precedence(yaml_path):
 def test_env_var_precedence(yaml_path):
     """Test that env_var has precedence over yaml values"""
     config = Configuration()
-    config.add_option('test', option_type=str, default="voici_voila", env_var="TOP_SECRET_MESSAGE")
+    config.add_option(
+        "test", option_type=str, default="voici_voila", env_var="TOP_SECRET_MESSAGE"
+    )
     assert config.test == "voici_voila"
 
     config.load_yaml(yaml_path)
     assert config.test == "from my yaml!"
 
-    os.environ['TOP_SECRET_MESSAGE'] = 'coussi_coussa'
+    os.environ["TOP_SECRET_MESSAGE"] = "coussi_coussa"
     assert config.test == "coussi_coussa"
-    del os.environ['TOP_SECRET_MESSAGE']
+    del os.environ["TOP_SECRET_MESSAGE"]
 
     assert config.test == "from my yaml!"
 
@@ -253,29 +268,33 @@ def test_env_var_precedence(yaml_path):
 def test_env_var_list(yaml_path):
     """Test that env_var lists are correctly handled"""
     config = Configuration()
-    config.add_option('test', option_type=list, default=["voici"], env_var="TOP_SECRET_LIST")
+    config.add_option(
+        "test", option_type=list, default=["voici"], env_var="TOP_SECRET_LIST"
+    )
     assert config.test == ["voici"]
 
-    os.environ['TOP_SECRET_LIST'] = 'voila:voici:voila'
-    assert config.test == ['voila', 'voici', 'voila']
+    os.environ["TOP_SECRET_LIST"] = "voila:voici:voila"
+    assert config.test == ["voila", "voici", "voila"]
 
 
 def test_local_precedence(yaml_path):
     """Test local setting has precedence over env var values"""
     config = Configuration()
-    config.add_option('test', option_type=str, default="voici_voila", env_var="TOP_SECRET_MESSAGE")
+    config.add_option(
+        "test", option_type=str, default="voici_voila", env_var="TOP_SECRET_MESSAGE"
+    )
     assert config.test == "voici_voila"
 
     config.load_yaml(yaml_path)
     assert config.test == "from my yaml!"
 
-    os.environ['TOP_SECRET_MESSAGE'] = 'coussi_coussa'
+    os.environ["TOP_SECRET_MESSAGE"] = "coussi_coussa"
     assert config.test == "coussi_coussa"
 
     config.test = "comme_ci_comme_ca"
     assert config.test == "comme_ci_comme_ca"
 
-    del os.environ['TOP_SECRET_MESSAGE']
+    del os.environ["TOP_SECRET_MESSAGE"]
 
 
 def test_overwrite_subconfig():
@@ -283,7 +302,7 @@ def test_overwrite_subconfig():
     config = Configuration()
     config.nested = Configuration()
     with pytest.raises(ValueError) as exc:
-        config.add_option('nested', option_type=str)
+        config.add_option("nested", option_type=str)
     assert "Configuration already contains nested" == str(exc.value)
 
     with pytest.raises(ValueError) as exc:
@@ -294,139 +313,133 @@ def test_overwrite_subconfig():
 def test_load_yaml_with_dict_items(subdict_yaml_path):
     """Test that yaml config with items assigned with dicts is supported"""
     config = Configuration()
-    default = {'default': 'sub-dict'}
-    config.add_option('test', option_type=dict, default=default)
+    default = {"default": "sub-dict"}
+    config.add_option("test", option_type=dict, default=default)
     assert config.test == default
     config.test2 = Configuration()
-    config.test2.add_option('test', option_type=dict, default=default)
+    config.test2.add_option("test", option_type=dict, default=default)
     assert config.test2.test == default
 
     config.load_yaml(subdict_yaml_path)
-    assert config.test == {'i am': 'a sub-dict'}
-    assert config.test2.test == {'me is': 'sub-conf sub-dict'}
+    assert config.test == {"i am": "a sub-dict"}
+    assert config.test2.test == {"me is": "sub-conf sub-dict"}
 
 
 def test_load_yaml_unknown_option(broken_yaml_path):
     """Test error message when yaml config contains unknown options"""
     config = Configuration()
-    config.add_option('test', option_type=str, default='hello')
-    assert config.test == 'hello'
+    config.add_option("test", option_type=str, default="hello")
+    assert config.test == "hello"
 
     with pytest.raises(ConfigurationError) as exc:
         config.load_yaml(broken_yaml_path)
-    assert exc.match('Configuration does not have an attribute \'coucou\'')
+    assert exc.match("Configuration does not have an attribute 'coucou'")
 
 
 def test_to_dict():
     """Test dictionary representation of the configuration"""
     config = Configuration()
-    config.add_option('test', option_type=str, default="voici_voila")
+    config.add_option("test", option_type=str, default="voici_voila")
     config.nested = Configuration()
-    config.nested.add_option('test2', option_type=str, default="zici")
+    config.nested.add_option("test2", option_type=str, default="zici")
 
-    assert config.to_dict() == {
-        'test': 'voici_voila',
-        'nested': {
-            'test2': 'zici'}}
+    assert config.to_dict() == {"test": "voici_voila", "nested": {"test2": "zici"}}
 
-    config.test = 'hello'
-    config.nested.test2 = 'labas'
+    config.test = "hello"
+    config.nested.test2 = "labas"
 
-    assert config.to_dict() == {
-        'test': 'hello',
-        'nested': {
-            'test2': 'labas'}}
+    assert config.to_dict() == {"test": "hello", "nested": {"test2": "labas"}}
 
 
 def test_key_curation():
     """Test that both - and _ maps to same options"""
     config = Configuration()
-    config.add_option('test-with-dashes', option_type=int, default=1)
-    config.add_option('test_with_underscores', option_type=int, default=2)
-    config.add_option('test-all_mixedup', option_type=int, default=3)
+    config.add_option("test-with-dashes", option_type=int, default=1)
+    config.add_option("test_with_underscores", option_type=int, default=2)
+    config.add_option("test-all_mixedup", option_type=int, default=3)
 
-    assert config['test-with-dashes'] == 1
-    assert config['test_with_underscores'] == 2
-    assert config['test-all_mixedup'] == 3
+    assert config["test-with-dashes"] == 1
+    assert config["test_with_underscores"] == 2
+    assert config["test-all_mixedup"] == 3
 
-    assert config['test_with_dashes'] == 1
-    assert config['test-with-underscores'] == 2
-    assert config['test_all-mixedup'] == 3
+    assert config["test_with_dashes"] == 1
+    assert config["test-with-underscores"] == 2
+    assert config["test_all-mixedup"] == 3
 
     assert config.test_with_dashes == 1
     assert config.test_with_underscores == 2
     assert config.test_all_mixedup == 3
 
-    config['test_with_dashes'] = 4
-    assert config['test-with-dashes'] == 4
+    config["test_with_dashes"] = 4
+    assert config["test-with-dashes"] == 4
 
 
 def test_nested_key_curation():
     """Test that both - and _ maps to same options in nested configs as well"""
     config = Configuration()
-    config.add_option('test-with-dashes', option_type=str, default="voici_voila")
+    config.add_option("test-with-dashes", option_type=str, default="voici_voila")
     config.nested = Configuration()
-    config.nested.add_option('test_with_underscores', option_type=str, default="zici")
+    config.nested.add_option("test_with_underscores", option_type=str, default="zici")
 
-    assert config['nested']['test_with_underscores'] == 'zici'
-    assert config['nested']['test-with-underscores'] == 'zici'
+    assert config["nested"]["test_with_underscores"] == "zici"
+    assert config["nested"]["test-with-underscores"] == "zici"
 
-    config['nested']['test-with-underscores'] = 'labas'
-    assert config.nested.test_with_underscores == 'labas'
+    config["nested"]["test-with-underscores"] = "labas"
+    assert config.nested.test_with_underscores == "labas"
 
 
 def test_help_option():
     """Verify adding documentation to options."""
     config = Configuration()
-    config.add_option('option', option_type=str, help='A useless option!')
+    config.add_option("option", option_type=str, help="A useless option!")
 
-    assert config.help('option') == 'A useless option!'
+    assert config.help("option") == "A useless option!"
 
 
 def test_help_nested_option():
     """Verify adding documentation to a nested option."""
     config = Configuration()
-    config.add_option('option', option_type=str, help='A useless option!')
+    config.add_option("option", option_type=str, help="A useless option!")
     config.nested = Configuration()
-    config.nested.add_option('option', option_type=str, help='A useless nested option!')
+    config.nested.add_option("option", option_type=str, help="A useless nested option!")
 
-    assert config.help('nested.option') == 'A useless nested option!'
-    assert config.nested.help('option') == 'A useless nested option!'
+    assert config.help("nested.option") == "A useless nested option!"
+    assert config.nested.help("option") == "A useless nested option!"
 
 
 def test_help_option_with_default():
     """Verify adding documentation to options with default value."""
     config = Configuration()
-    config.add_option('option', option_type=str, default='a', help='A useless option!')
+    config.add_option("option", option_type=str, default="a", help="A useless option!")
 
-    assert config.help('option') == 'A useless option! (default: a)'
+    assert config.help("option") == "A useless option! (default: a)"
 
 
 def test_no_help_option():
     """Verify not adding documentation to options."""
     config = Configuration()
-    config.add_option('option', option_type=str)
+    config.add_option("option", option_type=str)
 
-    assert config.help('option') == 'Undocumented'
+    assert config.help("option") == "Undocumented"
 
 
 def test_argument_parser():
     """Verify the argument parser built based on config."""
     config = Configuration()
-    config.add_option('option', option_type=str)
+    config.add_option("option", option_type=str)
 
     parser = argparse.ArgumentParser()
     config.add_arguments(parser)
 
-    options = parser.parse_args(['--option', 'a'])
+    options = parser.parse_args(["--option", "a"])
 
-    assert options.option == 'a'
+    assert options.option == "a"
 
 
 def test_argument_parser_ignore_default():
     """Verify the argument parser does not get default values."""
     config = Configuration()
-    config.add_option('option', option_type=str, default='b')
+    config.add_option("option", option_type=str, default="b")
 
     parser = argparse.ArgumentParser()
     config.add_arguments(parser)
@@ -439,64 +452,70 @@ def test_argument_parser_ignore_default():
 def test_argument_parser_rename():
     """Verify the argument parser built based on config with some options renamed."""
     config = Configuration()
-    config.add_option('option', option_type=str)
+    config.add_option("option", option_type=str)
 
     parser = argparse.ArgumentParser()
-    config.add_arguments(parser, rename=dict(option='--new-option'))
+    config.add_arguments(parser, rename=dict(option="--new-option"))
 
     with pytest.raises(SystemExit) as exc:
-        options = parser.parse_args(['--option', 'a'])
+        options = parser.parse_args(["--option", "a"])
 
-    assert exc.match('2')
+    assert exc.match("2")
 
-    options = parser.parse_args(['--new-option', 'a'])
+    options = parser.parse_args(["--new-option", "a"])
 
-    assert options.new_option == 'a'
+    assert options.new_option == "a"
 
 
 def test_argument_parser_dict_list_tuple():
     """Verify the argument parser does not contain options of type dict/list/tuple in config."""
     config = Configuration()
-    config.add_option('st', option_type=str)
-    config.add_option('di', option_type=dict)
-    config.add_option('li', option_type=list)
-    config.add_option('tu', option_type=tuple)
+    config.add_option("st", option_type=str)
+    config.add_option("di", option_type=dict)
+    config.add_option("li", option_type=list)
+    config.add_option("tu", option_type=tuple)
 
     parser = argparse.ArgumentParser()
     config.add_arguments(parser)
 
     options = parser.parse_args([])
-    assert vars(options) == {'st': None}
+    assert vars(options) == {"st": None}
 
     with pytest.raises(SystemExit) as exc:
-        options = parser.parse_args(['--di', 'ct'])
+        options = parser.parse_args(["--di", "ct"])
 
-    assert exc.match('2')
+    assert exc.match("2")
 
 
 def test_deprecate_option(caplog):
     """Test deprecating an option."""
     config = Configuration()
     config.add_option(
-        'option', option_type=str, default='hello',
-        deprecate=dict(version='v1.0', alternative='None! T_T'))
+        "option",
+        option_type=str,
+        default="hello",
+        deprecate=dict(version="v1.0", alternative="None! T_T"),
+    )
 
-    config.add_option(
-        'ok', option_type=str, default='hillo')
+    config.add_option("ok", option_type=str, default="hillo")
 
     # Access the deprecated option and trigger a warning.
     with caplog.at_level(logging.WARNING, logger="orion.core.io.config"):
-        assert config.option == 'hello'
+        assert config.option == "hello"
 
-    assert caplog.record_tuples == [(
-        'orion.core.io.config', logging.WARNING,
-        '(DEPRECATED) Option `option` will be removed in v1.0. Use `None! T_T` instead.')]
+    assert caplog.record_tuples == [
+        (
+            "orion.core.io.config",
+            logging.WARNING,
+            "(DEPRECATED) Option `option` will be removed in v1.0. Use `None! T_T` instead.",
+        )
+    ]
 
     caplog.clear()
 
     # Access the non-deprecated option and trigger no warnings.
     with caplog.at_level(logging.WARNING, logger="orion.core.io.config"):
-        assert config.ok == 'hillo'
+        assert config.ok == "hillo"
 
     assert caplog.record_tuples == []
 
@@ -506,80 +525,103 @@ def test_deprecate_option_missing_version():
     config = Configuration()
     with pytest.raises(ValueError) as exc:
         config.add_option(
-            'option', option_type=str,
-            deprecate=dict(alternative='None! T_T'))
+            "option", option_type=str, deprecate=dict(alternative="None! T_T")
+        )
 
-    assert exc.match('`version` is missing in deprecate option')
+    assert exc.match("`version` is missing in deprecate option")
 
 
 def test_deprecate_option_no_alternative(caplog):
     """Verify option deprecation when there is no alternative."""
     config = Configuration()
     config.add_option(
-        'option', option_type=str, default='hello',
-        deprecate=dict(version='v1.0'))
+        "option", option_type=str, default="hello", deprecate=dict(version="v1.0")
+    )
 
     # Access the deprecated option and trigger a warning.
     with caplog.at_level(logging.WARNING, logger="orion.core.io.config"):
-        assert config.option == 'hello'
+        assert config.option == "hello"
 
-    assert caplog.record_tuples == [(
-        'orion.core.io.config', logging.WARNING,
-        '(DEPRECATED) Option `option` will be removed in v1.0.')]
+    assert caplog.record_tuples == [
+        (
+            "orion.core.io.config",
+            logging.WARNING,
+            "(DEPRECATED) Option `option` will be removed in v1.0.",
+        )
+    ]
 
 
 def test_deprecate_option_help():
     """Verify help message of a deprecated option."""
     config = Configuration()
     config.add_option(
-        'option', option_type=str,
-        deprecate=dict(version='v1.0', alternative='None! T_T'),
-        help='A useless option!')
+        "option",
+        option_type=str,
+        deprecate=dict(version="v1.0", alternative="None! T_T"),
+        help="A useless option!",
+    )
 
-    assert config.help('option') == '(DEPRECATED) A useless option!'
+    assert config.help("option") == "(DEPRECATED) A useless option!"
 
 
 def test_deprecate_option_print_with_different_name(caplog):
     """Verify deprecation warning with different name (for nested options)."""
     config = Configuration()
     config.add_option(
-        'option', option_type=str, default='hello',
-        deprecate=dict(version='v1.0', alternative='None! T_T', name='nested.option'))
+        "option",
+        option_type=str,
+        default="hello",
+        deprecate=dict(version="v1.0", alternative="None! T_T", name="nested.option"),
+    )
 
     # Access the deprecated option and trigger a warning.
     with caplog.at_level(logging.WARNING, logger="orion.core.io.config"):
-        assert config.option == 'hello'
+        assert config.option == "hello"
 
-    assert caplog.record_tuples == [(
-        'orion.core.io.config', logging.WARNING,
-        '(DEPRECATED) Option `nested.option` will be removed in v1.0. Use `None! T_T` instead.')]
+    assert caplog.record_tuples == [
+        (
+            "orion.core.io.config",
+            logging.WARNING,
+            "(DEPRECATED) Option `nested.option` will be removed in v1.0. Use `None! T_T` instead.",
+        )
+    ]
 
 
 def test_get_deprecated_key(caplog):
     """Verify deprecation warning using get()."""
     config = Configuration()
     config.add_option(
-        'option', option_type=str, default='hello',
-        deprecate=dict(version='v1.0', alternative='None! T_T'))
+        "option",
+        option_type=str,
+        default="hello",
+        deprecate=dict(version="v1.0", alternative="None! T_T"),
+    )
 
     # Access the deprecated option and trigger a warning.
     with caplog.at_level(logging.WARNING, logger="orion.core.io.config"):
-        assert config.get('option') == 'hello'
+        assert config.get("option") == "hello"
 
-    assert caplog.record_tuples == [(
-        'orion.core.io.config', logging.WARNING,
-        '(DEPRECATED) Option `option` will be removed in v1.0. Use `None! T_T` instead.')]
+    assert caplog.record_tuples == [
+        (
+            "orion.core.io.config",
+            logging.WARNING,
+            "(DEPRECATED) Option `option` will be removed in v1.0. Use `None! T_T` instead.",
+        )
+    ]
 
 
 def test_get_deprecated_key_ignore_warning(caplog):
     """Verify deprecation warning using get(deprecated='ignore')."""
     config = Configuration()
     config.add_option(
-        'option', option_type=str, default='hello',
-        deprecate=dict(version='v1.0', alternative='None! T_T'))
+        "option",
+        option_type=str,
+        default="hello",
+        deprecate=dict(version="v1.0", alternative="None! T_T"),
+    )
 
     # Access the deprecated option and trigger a warning.
     with caplog.at_level(logging.WARNING, logger="orion.core.io.config"):
-        assert config.get('option', deprecated='ignore') == 'hello'
+        assert config.get("option", deprecated="ignore") == "hello"
 
     assert caplog.record_tuples == []
